# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mt5-term-api-subscriptions.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import mrpc_mt5_error_pb2 as mrpc__mt5__error__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n mt5-term-api-subscriptions.proto\x12\x0cmt5_term_api\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x14mrpc-mt5-error.proto\"\x1b\n\x19OnTradeTransactionRequest\"\x81\x01\n\x17OnTradeTransactionReply\x12\x34\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32$.mt5_term_api.OnTradeTransactionDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"\xd6\x02\n\x16OnTradeTransactionData\x12\x39\n\x04type\x18\x01 \x01(\x0e\x32+.mt5_term_api.MT5_SUB_ENUM_EVENT_GROUP_TYPE\x12<\n\x11trade_transaction\x18\x02 \x01(\x0b\x32!.mt5_term_api.MqlTradeTransaction\x12\x34\n\rtrade_request\x18\x03 \x01(\x0b\x32\x1d.mt5_term_api.MqlTradeRequest\x12\x32\n\x0ctrade_result\x18\x04 \x01(\x0b\x32\x1c.mt5_term_api.MqlTradeResult\x12!\n\x19terminal_instance_guid_id\x18\x05 \x01(\t\x12\x36\n\x0c\x61\x63\x63ount_info\x18\x06 \x01(\x0b\x32 .mt5_term_api.OnEventAccountInfo\"\xe3\x04\n\x13MqlTradeTransaction\x12\x13\n\x0b\x64\x65\x61l_ticket\x18\x01 \x01(\x04\x12\x14\n\x0corder_ticket\x18\x02 \x01(\x04\x12\x0e\n\x06symbol\x18\x03 \x01(\t\x12;\n\x04type\x18\x04 \x01(\x0e\x32-.mt5_term_api.SUB_ENUM_TRADE_TRANSACTION_TYPE\x12\x35\n\norder_type\x18\x05 \x01(\x0e\x32!.mt5_term_api.SUB_ENUM_ORDER_TYPE\x12\x37\n\x0border_state\x18\x06 \x01(\x0e\x32\".mt5_term_api.SUB_ENUM_ORDER_STATE\x12\x33\n\tdeal_type\x18\x07 \x01(\x0e\x32 .mt5_term_api.SUB_ENUM_DEAL_TYPE\x12?\n\x0forder_time_type\x18\x08 \x01(\x0e\x32&.mt5_term_api.SUB_ENUM_ORDER_TYPE_TIME\x12\x39\n\x15order_expiration_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05price\x18\n \x01(\x01\x12 \n\x18price_trigger_stop_limit\x18\x0b \x01(\x01\x12\x17\n\x0fprice_stop_loss\x18\x0c \x01(\x01\x12\x19\n\x11price_take_profit\x18\r \x01(\x01\x12\x0e\n\x06volume\x18\x0e \x01(\x01\x12\x17\n\x0fposition_ticket\x18\x0f \x01(\x04\x12%\n\x1dposition_by_opposite_position\x18\x10 \x01(\x04\"\xdf\x04\n\x0fMqlTradeRequest\x12J\n\x14trade_operation_type\x18\x01 \x01(\x0e\x32,.mt5_term_api.SUB_ENUM_TRADE_REQUEST_ACTIONS\x12\r\n\x05magic\x18\x02 \x01(\x04\x12\x14\n\x0corder_ticket\x18\x03 \x01(\x04\x12\x0e\n\x06symbol\x18\x04 \x01(\t\x12\"\n\x1arequested_deal_volume_lots\x18\x05 \x01(\x01\x12\r\n\x05price\x18\x06 \x01(\x01\x12\x12\n\nstopl_imit\x18\x07 \x01(\x01\x12\x11\n\tstop_loss\x18\x08 \x01(\x01\x12\x13\n\x0btake_profit\x18\t \x01(\x01\x12\x11\n\tdeviation\x18\n \x01(\x04\x12\x35\n\norder_type\x18\x0b \x01(\x0e\x32!.mt5_term_api.SUB_ENUM_ORDER_TYPE\x12\x45\n\x12order_type_filling\x18\x0c \x01(\x0e\x32).mt5_term_api.SUB_ENUM_ORDER_TYPE_FILLING\x12\x39\n\ttype_time\x18\r \x01(\x0e\x32&.mt5_term_api.SUB_ENUM_ORDER_TYPE_TIME\x12\x39\n\x15order_expiration_time\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\rorder_comment\x18\x0f \x01(\t\x12\x17\n\x0fposition_ticket\x18\x10 \x01(\x04\x12%\n\x1dposition_by_opposite_position\x18\x11 \x01(\x04\"\xd2\x02\n\x0eMqlTradeResult\x12\x1d\n\x15trade_return_int_code\x18\x01 \x01(\r\x12:\n\x11trade_return_code\x18\x02 \x01(\x0e\x32\x1f.mt5_term_api.MqlErrorTradeCode\x12\x13\n\x0b\x64\x65\x61l_ticket\x18\x03 \x01(\x04\x12\x14\n\x0corder_ticket\x18\x04 \x01(\x04\x12\x13\n\x0b\x64\x65\x61l_volume\x18\x05 \x01(\x01\x12\x12\n\ndeal_price\x18\x06 \x01(\x01\x12\x13\n\x0b\x63urrent_bid\x18\x07 \x01(\x01\x12\x13\n\x0b\x63urrent_ask\x18\x08 \x01(\x01\x12#\n\x1b\x62roker_comment_to_operation\x18\t \x01(\t\x12$\n\x1cterminal_dispatch_request_id\x18\n \x01(\r\x12\x1c\n\x14return_code_external\x18\x0b \x01(\x05\"N\n)OnPositionsAndPendingOrdersTicketsRequest\x12!\n\x19timer_period_milliseconds\x18\x01 \x01(\x05\"\xa1\x01\n\'OnPositionsAndPendingOrdersTicketsReply\x12\x44\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x34.mt5_term_api.OnPositionsAndPendingOrdersTicketsDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"\xb5\x01\n&OnPositionsAndPendingOrdersTicketsData\x12\x18\n\x10position_tickets\x18\x01 \x03(\x04\x12\x1d\n\x15pending_order_tickets\x18\x02 \x03(\x04\x12/\n\x0bserver_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12!\n\x19terminal_instance_guid_id\x18\x04 \x01(\t\"}\n\x15OnPositionProfitReply\x12\x32\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\".mt5_term_api.OnPositionProfitDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"\xfd\x02\n\x14OnPositionProfitData\x12\x39\n\x04type\x18\x01 \x01(\x0e\x32+.mt5_term_api.MT5_SUB_ENUM_EVENT_GROUP_TYPE\x12\x41\n\rnew_positions\x18\x02 \x03(\x0b\x32*.mt5_term_api.OnPositionProfitPositionInfo\x12\x45\n\x11updated_positions\x18\x03 \x03(\x0b\x32*.mt5_term_api.OnPositionProfitPositionInfo\x12\x45\n\x11\x64\x65leted_positions\x18\x04 \x03(\x0b\x32*.mt5_term_api.OnPositionProfitPositionInfo\x12\x36\n\x0c\x61\x63\x63ount_info\x18\x05 \x01(\x0b\x32 .mt5_term_api.OnEventAccountInfo\x12!\n\x19terminal_instance_guid_id\x18\x06 \x01(\t\"W\n\x17OnPositionProfitRequest\x12!\n\x19timer_period_milliseconds\x18\x01 \x01(\x05\x12\x19\n\x11ignore_empty_data\x18\x02 \x01(\x08\"f\n\x1cOnPositionProfitPositionInfo\x12\r\n\x05index\x18\x01 \x01(\x05\x12\x0e\n\x06ticket\x18\x02 \x01(\x03\x12\x0e\n\x06profit\x18\x03 \x01(\x01\x12\x17\n\x0fposition_symbol\x18\x04 \x01(\t\"\x9f\x01\n\x12OnEventAccountInfo\x12\x0f\n\x07\x62\x61lance\x18\x01 \x01(\x01\x12\x0e\n\x06\x63redit\x18\x02 \x01(\x01\x12\x0e\n\x06\x65quity\x18\x03 \x01(\x01\x12\x0e\n\x06margin\x18\x04 \x01(\x01\x12\x13\n\x0b\x66ree_margin\x18\x05 \x01(\x01\x12\x0e\n\x06profit\x18\x06 \x01(\x01\x12\x14\n\x0cmargin_level\x18\x07 \x01(\x01\x12\r\n\x05login\x18\x08 \x01(\x03\"\x10\n\x0eOnTradeRequest\"k\n\x0cOnTradeReply\x12)\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x19.mt5_term_api.OnTradeDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"\xd6\x01\n\x0bOnTradeData\x12\x39\n\x04type\x18\x01 \x01(\x0e\x32+.mt5_term_api.MT5_SUB_ENUM_EVENT_GROUP_TYPE\x12\x31\n\nevent_data\x18\x02 \x01(\x0b\x32\x1d.mt5_term_api.OnTadeEventData\x12\x36\n\x0c\x61\x63\x63ount_info\x18\x03 \x01(\x0b\x32 .mt5_term_api.OnEventAccountInfo\x12!\n\x19terminal_instance_guid_id\x18\x04 \x01(\t\"\x81\x06\n\x10OnTradeOrderInfo\x12\r\n\x05index\x18\x01 \x01(\x05\x12\x0e\n\x06ticket\x18\x02 \x01(\x03\x12\x31\n\x05state\x18\x03 \x01(\x0e\x32\".mt5_term_api.SUB_ENUM_ORDER_STATE\x12\x16\n\x0esetup_time_msc\x18\x04 \x01(\x03\x12\x11\n\tstop_loss\x18\x05 \x01(\x01\x12\x13\n\x0btake_profit\x18\x06 \x01(\x01\x12\x12\n\nstop_limit\x18\x07 \x01(\x01\x12\x15\n\rprice_current\x18\x08 \x01(\x01\x12\x33\n\x0ftime_expiration\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\ttime_type\x18\n \x01(\x0e\x32&.mt5_term_api.SUB_ENUM_ORDER_TYPE_TIME\x12\x0f\n\x07\x63omment\x18\x0b \x01(\t\x12\x0e\n\x06symbol\x18\x0c \x01(\t\x12\r\n\x05magic\x18\r \x01(\x03\x12\x12\n\nprice_open\x18\x0e \x01(\x01\x12.\n\nsetup_time\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1f\n\x17time_expiration_seconds\x18\x10 \x01(\x03\x12\x16\n\x0evolume_current\x18\x11 \x01(\x01\x12\x16\n\x0evolume_initial\x18\x12 \x01(\x01\x12\x15\n\raccount_login\x18\x13 \x01(\x03\x12\x35\n\norder_type\x18\x14 \x01(\x0e\x32!.mt5_term_api.SUB_ENUM_ORDER_TYPE\x12\x45\n\x12order_type_filling\x18\x15 \x01(\x0e\x32).mt5_term_api.SUB_ENUM_ORDER_TYPE_FILLING\x12\x39\n\x0corder_reason\x18\x16 \x01(\x0e\x32#.mt5_term_api.SUB_ENUM_ORDER_REASON\x12\x13\n\x0bposition_id\x18\x17 \x01(\x03\x12\x16\n\x0eposition_by_id\x18\x18 \x01(\x03\"\xdd\x03\n\x13OnTradePositionInfo\x12\r\n\x05index\x18\x01 \x01(\x05\x12\x0e\n\x06ticket\x18\x02 \x01(\x03\x12\x32\n\x04type\x18\x03 \x01(\x0e\x32$.mt5_term_api.SUB_ENUM_POSITION_TYPE\x12\x31\n\rposition_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10last_update_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nprice_open\x18\x06 \x01(\x01\x12\x0e\n\x06profit\x18\x07 \x01(\x01\x12\n\n\x02sl\x18\x08 \x01(\x01\x12\n\n\x02tp\x18\t \x01(\x01\x12\x0e\n\x06volume\x18\n \x01(\x01\x12\x0c\n\x04swap\x18\x0b \x01(\x01\x12\x0f\n\x07\x63omment\x18\x0c \x01(\t\x12\x0e\n\x06symbol\x18\r \x01(\t\x12\r\n\x05magic\x18\x0e \x01(\x03\x12\x15\n\rprice_current\x18\x0f \x01(\x01\x12\x15\n\raccount_login\x18\x10 \x01(\x03\x12\x36\n\x06reason\x18\x11 \x01(\x0e\x32&.mt5_term_api.SUB_ENUM_POSITION_REASON\x12\x1a\n\x12\x66rom_pending_order\x18\x12 \x01(\x08\"\xe9\x03\n\x16OnTradeHistoryDealInfo\x12\r\n\x05index\x18\x01 \x01(\x05\x12\x0e\n\x06ticket\x18\x02 \x01(\x04\x12\x14\n\x0corder_ticket\x18\x03 \x01(\x03\x12.\n\x04type\x18\x04 \x01(\x0e\x32 .mt5_term_api.SUB_ENUM_DEAL_TYPE\x12-\n\tdeal_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x05\x65ntry\x18\x06 \x01(\x0e\x32!.mt5_term_api.SUB_ENUM_DEAL_ENTRY\x12\x18\n\x10\x64\x65\x61l_position_id\x18\x07 \x01(\x03\x12\x12\n\ncommission\x18\x08 \x01(\x01\x12\x0b\n\x03\x66\x65\x65\x18\t \x01(\x01\x12\r\n\x05price\x18\n \x01(\x01\x12\x0e\n\x06profit\x18\x0b \x01(\x01\x12\n\n\x02sl\x18\x0c \x01(\x01\x12\n\n\x02tp\x18\r \x01(\x01\x12\x0e\n\x06volume\x18\x0e \x01(\x01\x12\x0f\n\x07\x63omment\x18\x0f \x01(\t\x12\x0e\n\x06symbol\x18\x10 \x01(\t\x12\x0c\n\x04swap\x18\x11 \x01(\x01\x12\x32\n\x06reason\x18\x12 \x01(\x0e\x32\".mt5_term_api.SUB_ENUM_DEAL_REASON\x12\r\n\x05magic\x18\x13 \x01(\x03\x12\x15\n\raccount_login\x18\x14 \x01(\x03\"\x95\x06\n\x17OnTradeHistoryOrderInfo\x12\r\n\x05index\x18\x01 \x01(\x05\x12\x0e\n\x06ticket\x18\x02 \x01(\x03\x12\x31\n\x05state\x18\x03 \x01(\x0e\x32\".mt5_term_api.SUB_ENUM_ORDER_STATE\x12.\n\nsetup_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tdone_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x0ftime_expiration\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0bposition_id\x18\x07 \x01(\x04\x12\x39\n\ttype_time\x18\x08 \x01(\x0e\x32&.mt5_term_api.SUB_ENUM_ORDER_TYPE_TIME\x12\x11\n\tstop_loss\x18\t \x01(\x01\x12\x13\n\x0btake_profit\x18\n \x01(\x01\x12\x12\n\nstop_limit\x18\x0b \x01(\x01\x12\x15\n\rprice_current\x18\x0c \x01(\x01\x12\x12\n\nprice_open\x18\r \x01(\x01\x12\x16\n\x0evolume_current\x18\x0e \x01(\x01\x12\x16\n\x0evolume_initial\x18\x0f \x01(\x01\x12\r\n\x05magic\x18\x13 \x01(\x03\x12\x13\n\x0bposition_by\x18\x14 \x01(\x03\x12\x32\n\x06reason\x18\x15 \x01(\x0e\x32\".mt5_term_api.SUB_ENUM_DEAL_REASON\x12\x0f\n\x07\x63omment\x18\x16 \x01(\t\x12\x0e\n\x06symbol\x18\x17 \x01(\t\x12\x1f\n\x17time_expiration_seconds\x18\x18 \x01(\x03\x12\x15\n\raccount_login\x18\x19 \x01(\x03\x12\x35\n\norder_type\x18\x1a \x01(\x0e\x32!.mt5_term_api.SUB_ENUM_ORDER_TYPE\x12\x45\n\x12order_type_filling\x18\x1b \x01(\x0e\x32).mt5_term_api.SUB_ENUM_ORDER_TYPE_FILLING\"\x88\x01\n\x17OnTradeOrderStateChange\x12\x36\n\x0eprevious_order\x18\x01 \x01(\x0b\x32\x1e.mt5_term_api.OnTradeOrderInfo\x12\x35\n\rcurrent_order\x18\x02 \x01(\x0b\x32\x1e.mt5_term_api.OnTradeOrderInfo\"\x92\x01\n\x15OnTradePositionUpdate\x12<\n\x11previous_position\x18\x01 \x01(\x0b\x32!.mt5_term_api.OnTradePositionInfo\x12;\n\x10\x63urrent_position\x18\x02 \x01(\x0b\x32!.mt5_term_api.OnTradePositionInfo\"\xa3\x01\n\x18OnTradeHistoryDealUpdate\x12\x43\n\x15previous_history_deal\x18\x01 \x01(\x0b\x32$.mt5_term_api.OnTradeHistoryDealInfo\x12\x42\n\x14\x63urrent_history_deal\x18\x02 \x01(\x0b\x32$.mt5_term_api.OnTradeHistoryDealInfo\"\xa8\x01\n\x19OnTradeHistoryOrderUpdate\x12\x45\n\x16previous_history_order\x18\x01 \x01(\x0b\x32%.mt5_term_api.OnTradeHistoryOrderInfo\x12\x44\n\x15\x63urrent_history_order\x18\x02 \x01(\x0b\x32%.mt5_term_api.OnTradeHistoryOrderInfo\"\xaa\x06\n\x0fOnTadeEventData\x12\x32\n\nnew_orders\x18\x01 \x03(\x0b\x32\x1e.mt5_term_api.OnTradeOrderInfo\x12:\n\x12\x64isappeared_orders\x18\x02 \x03(\x0b\x32\x1e.mt5_term_api.OnTradeOrderInfo\x12\x43\n\x14state_changed_orders\x18\x03 \x03(\x0b\x32%.mt5_term_api.OnTradeOrderStateChange\x12\x41\n\x12new_history_orders\x18\x04 \x03(\x0b\x32%.mt5_term_api.OnTradeHistoryOrderInfo\x12I\n\x1a\x64isappeared_history_orders\x18\x05 \x03(\x0b\x32%.mt5_term_api.OnTradeHistoryOrderInfo\x12G\n\x16updated_history_orders\x18\x06 \x03(\x0b\x32\'.mt5_term_api.OnTradeHistoryOrderUpdate\x12?\n\x11new_history_deals\x18\x07 \x03(\x0b\x32$.mt5_term_api.OnTradeHistoryDealInfo\x12G\n\x19\x64isappeared_history_deals\x18\x08 \x03(\x0b\x32$.mt5_term_api.OnTradeHistoryDealInfo\x12\x45\n\x15updated_history_deals\x18\t \x03(\x0b\x32&.mt5_term_api.OnTradeHistoryDealUpdate\x12\x38\n\rnew_positions\x18\n \x03(\x0b\x32!.mt5_term_api.OnTradePositionInfo\x12@\n\x15\x64isappeared_positions\x18\x0b \x03(\x0b\x32!.mt5_term_api.OnTradePositionInfo\x12>\n\x11updated_positions\x18\x0c \x03(\x0b\x32#.mt5_term_api.OnTradePositionUpdate\"+\n\x13OnSymbolTickRequest\x12\x14\n\x0csymbol_names\x18\x01 \x03(\t\"u\n\x11OnSymbolTickReply\x12.\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1e.mt5_term_api.OnSymbolTickDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"q\n\x10OnSymbolTickData\x12:\n\x0bsymbol_tick\x18\x01 \x01(\x0b\x32%.mt5_term_api.MrpcSubscriptionMqlTick\x12!\n\x19terminal_instance_guid_id\x18\x02 \x01(\t\"\xc1\x01\n\x17MrpcSubscriptionMqlTick\x12(\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0b\n\x03\x62id\x18\x02 \x01(\x01\x12\x0b\n\x03\x61sk\x18\x03 \x01(\x01\x12\x0c\n\x04last\x18\x04 \x01(\x01\x12\x0e\n\x06volume\x18\x05 \x01(\x04\x12\x10\n\x08time_msc\x18\x06 \x01(\x03\x12\r\n\x05\x66lags\x18\x07 \x01(\r\x12\x13\n\x0bvolume_real\x18\x08 \x01(\x01\x12\x0e\n\x06symbol\x18\t \x01(\t*\xca\x03\n\x1fSUB_ENUM_TRADE_TRANSACTION_TYPE\x12#\n\x1fSUB_TRADE_TRANSACTION_ORDER_ADD\x10\x00\x12&\n\"SUB_TRADE_TRANSACTION_ORDER_UPDATE\x10\x01\x12&\n\"SUB_TRADE_TRANSACTION_ORDER_DELETE\x10\x02\x12\"\n\x1eSUB_TRADE_TRANSACTION_DEAL_ADD\x10\x03\x12%\n!SUB_TRADE_TRANSACTION_DEAL_UPDATE\x10\x04\x12%\n!SUB_TRADE_TRANSACTION_DEAL_DELETE\x10\x05\x12%\n!SUB_TRADE_TRANSACTION_HISTORY_ADD\x10\x06\x12(\n$SUB_TRADE_TRANSACTION_HISTORY_UPDATE\x10\x07\x12(\n$SUB_TRADE_TRANSACTION_HISTORY_DELETE\x10\x08\x12\"\n\x1eSUB_TRADE_TRANSACTION_POSITION\x10\t\x12!\n\x1dSUB_TRADE_TRANSACTION_REQUEST\x10\n*\xed\x01\n\x1eSUB_ENUM_TRADE_REQUEST_ACTIONS\x12\x1e\n\x1aSUB_TRADE_ACTION_UNDEFINED\x10\x00\x12\x19\n\x15SUB_TRADE_ACTION_DEAL\x10\x01\x12\x1c\n\x18SUB_TRADE_ACTION_PENDING\x10\x02\x12\x19\n\x15SUB_TRADE_ACTION_SLTP\x10\x03\x12\x1b\n\x17SUB_TRADE_ACTION_MODIFY\x10\x04\x12\x1b\n\x17SUB_TRADE_ACTION_REMOVE\x10\x05\x12\x1d\n\x19SUB_TRADE_ACTION_CLOSE_BY\x10\x06*\xd3\x01\n\x15SUB_ENUM_ORDER_REASON\x12\x1b\n\x17SUB_ORDER_REASON_CLIENT\x10\x00\x12\x1b\n\x17SUB_ORDER_REASON_MOBILE\x10\x02\x12\x18\n\x14SUB_ORDER_REASON_WEB\x10\x03\x12\x1b\n\x17SUB_ORDER_REASON_EXPERT\x10\x04\x12\x17\n\x13SUB_ORDER_REASON_SL\x10\x05\x12\x17\n\x13SUB_ORDER_REASON_TP\x10\x06\x12\x17\n\x13SUB_ORDER_REASON_SO\x10\x07*\x8c\x01\n\x1bSUB_ENUM_ORDER_TYPE_FILLING\x12\x19\n\x15SUB_ORDER_FILLING_FOK\x10\x00\x12\x19\n\x15SUB_ORDER_FILLING_IOC\x10\x01\x12\x19\n\x15SUB_ORDER_FILLING_BOC\x10\x02\x12\x1c\n\x18SUB_ORDER_FILLING_RETURN\x10\x03*\xa2\x02\n\x13SUB_ENUM_ORDER_TYPE\x12\x16\n\x12SUB_ORDER_TYPE_BUY\x10\x00\x12\x17\n\x13SUB_ORDER_TYPE_SELL\x10\x01\x12\x1c\n\x18SUB_ORDER_TYPE_BUY_LIMIT\x10\x02\x12\x1d\n\x19SUB_ORDER_TYPE_SELL_LIMIT\x10\x03\x12\x1b\n\x17SUB_ORDER_TYPE_BUY_STOP\x10\x04\x12\x1c\n\x18SUB_ORDER_TYPE_SELL_STOP\x10\x05\x12!\n\x1dSUB_ORDER_TYPE_BUY_STOP_LIMIT\x10\x06\x12\"\n\x1eSUB_ORDER_TYPE_SELL_STOP_LIMIT\x10\x07\x12\x1b\n\x17SUB_ORDER_TYPE_CLOSE_BY\x10\x08*\x8a\x01\n\x18SUB_ENUM_ORDER_TYPE_TIME\x12\x16\n\x12SUB_ORDER_TIME_GTC\x10\x00\x12\x16\n\x12SUB_ORDER_TIME_DAY\x10\x01\x12\x1c\n\x18SUB_ORDER_TIME_SPECIFIED\x10\x02\x12 \n\x1cSUB_ORDER_TIME_SPECIFIED_DAY\x10\x03*\xca\x02\n\x14SUB_ENUM_ORDER_STATE\x12\x1b\n\x17SUB_ORDER_STATE_STARTED\x10\x00\x12\x1a\n\x16SUB_ORDER_STATE_PLACED\x10\x01\x12\x1c\n\x18SUB_ORDER_STATE_CANCELED\x10\x02\x12\x1b\n\x17SUB_ORDER_STATE_PARTIAL\x10\x03\x12\x1a\n\x16SUB_ORDER_STATE_FILLED\x10\x04\x12\x1c\n\x18SUB_ORDER_STATE_REJECTED\x10\x05\x12\x1b\n\x17SUB_ORDER_STATE_EXPIRED\x10\x06\x12\x1f\n\x1bSUB_ORDER_STATE_REQUEST_ADD\x10\x07\x12\"\n\x1eSUB_ORDER_STATE_REQUEST_MODIFY\x10\x08\x12\"\n\x1eSUB_ORDER_STATE_REQUEST_CANCEL\x10\t*\x97\x01\n\x18SUB_ENUM_POSITION_REASON\x12\x1e\n\x1aSUB_POSITION_REASON_CLIENT\x10\x00\x12\x1e\n\x1aSUB_POSITION_REASON_MOBILE\x10\x02\x12\x1b\n\x17SUB_POSITION_REASON_WEB\x10\x03\x12\x1e\n\x1aSUB_POSITION_REASON_EXPERT\x10\x04*O\n\x16SUB_ENUM_POSITION_TYPE\x12\x19\n\x15SUB_POSITION_TYPE_BUY\x10\x00\x12\x1a\n\x16SUB_POSITION_TYPE_SELL\x10\x01*\xc7\x02\n\x14SUB_ENUM_DEAL_REASON\x12\x1a\n\x16SUB_DEAL_REASON_CLIENT\x10\x00\x12\x1a\n\x16SUB_DEAL_REASON_MOBILE\x10\x01\x12\x17\n\x13SUB_DEAL_REASON_WEB\x10\x02\x12\x1a\n\x16SUB_DEAL_REASON_EXPERT\x10\x03\x12\x16\n\x12SUB_DEAL_REASON_SL\x10\x04\x12\x16\n\x12SUB_DEAL_REASON_TP\x10\x05\x12\x16\n\x12SUB_DEAL_REASON_SO\x10\x06\x12\x1c\n\x18SUB_DEAL_REASON_ROLLOVER\x10\x07\x12\x1b\n\x17SUB_DEAL_REASON_VMARGIN\x10\x08\x12\x19\n\x15SUB_DEAL_REASON_SPLIT\x10\t\x12$\n SUB_DEAL_REASON_CORPORATE_ACTION\x10\n*\xac\x04\n\x12SUB_ENUM_DEAL_TYPE\x12\x15\n\x11SUB_DEAL_TYPE_BUY\x10\x00\x12\x16\n\x12SUB_DEAL_TYPE_SELL\x10\x01\x12\x19\n\x15SUB_DEAL_TYPE_BALANCE\x10\x02\x12\x18\n\x14SUB_DEAL_TYPE_CREDIT\x10\x03\x12\x18\n\x14SUB_DEAL_TYPE_CHARGE\x10\x04\x12\x1c\n\x18SUB_DEAL_TYPE_CORRECTION\x10\x05\x12\x17\n\x13SUB_DEAL_TYPE_BONUS\x10\x06\x12\x1c\n\x18SUB_DEAL_TYPE_COMMISSION\x10\x07\x12\"\n\x1eSUB_DEAL_TYPE_COMMISSION_DAILY\x10\x08\x12$\n SUB_DEAL_TYPE_COMMISSION_MONTHLY\x10\t\x12(\n$SUB_DEAL_TYPE_COMMISSION_AGENT_DAILY\x10\n\x12*\n&SUB_DEAL_TYPE_COMMISSION_AGENT_MONTHLY\x10\x0b\x12\x1a\n\x16SUB_DEAL_TYPE_INTEREST\x10\x0c\x12\x1e\n\x1aSUB_DEAL_TYPE_BUY_CANCELED\x10\r\x12\x1f\n\x1bSUB_DEAL_TYPE_SELL_CANCELED\x10\x0e\x12\x15\n\x11SUB_DEAL_DIVIDEND\x10\x0f\x12\x1d\n\x19SUB_DEAL_DIVIDEND_FRANKED\x10\x10\x12\x10\n\x0cSUB_DEAL_TAX\x10\x11*y\n\x13SUB_ENUM_DEAL_ENTRY\x12\x15\n\x11SUB_DEAL_ENTRY_IN\x10\x00\x12\x16\n\x12SUB_DEAL_ENTRY_OUT\x10\x01\x12\x18\n\x14SUB_DEAL_ENTRY_INOUT\x10\x02\x12\x19\n\x15SUB_DEAL_ENTRY_OUT_BY\x10\x03*A\n\x1dMT5_SUB_ENUM_EVENT_GROUP_TYPE\x12\x0f\n\x0bOrderProfit\x10\x00\x12\x0f\n\x0bOrderUpdate\x10\x01\x32\x95\x04\n\x13SubscriptionService\x12T\n\x0cOnSymbolTick\x12!.mt5_term_api.OnSymbolTickRequest\x1a\x1f.mt5_term_api.OnSymbolTickReply0\x01\x12\x45\n\x07OnTrade\x12\x1c.mt5_term_api.OnTradeRequest\x1a\x1a.mt5_term_api.OnTradeReply0\x01\x12`\n\x10OnPositionProfit\x12%.mt5_term_api.OnPositionProfitRequest\x1a#.mt5_term_api.OnPositionProfitReply0\x01\x12\x96\x01\n\"OnPositionsAndPendingOrdersTickets\x12\x37.mt5_term_api.OnPositionsAndPendingOrdersTicketsRequest\x1a\x35.mt5_term_api.OnPositionsAndPendingOrdersTicketsReply0\x01\x12\x66\n\x12OnTradeTransaction\x12\'.mt5_term_api.OnTradeTransactionRequest\x1a%.mt5_term_api.OnTradeTransactionReply0\x01\x42\x42Z1git.mtapi.io/root/mrpc-proto.git/mt5/libraries/go\xaa\x02\x0cmt5_term_apib\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mt5_term_api_subscriptions_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1git.mtapi.io/root/mrpc-proto.git/mt5/libraries/go\252\002\014mt5_term_api'
  _SUB_ENUM_TRADE_TRANSACTION_TYPE._serialized_start=8264
  _SUB_ENUM_TRADE_TRANSACTION_TYPE._serialized_end=8722
  _SUB_ENUM_TRADE_REQUEST_ACTIONS._serialized_start=8725
  _SUB_ENUM_TRADE_REQUEST_ACTIONS._serialized_end=8962
  _SUB_ENUM_ORDER_REASON._serialized_start=8965
  _SUB_ENUM_ORDER_REASON._serialized_end=9176
  _SUB_ENUM_ORDER_TYPE_FILLING._serialized_start=9179
  _SUB_ENUM_ORDER_TYPE_FILLING._serialized_end=9319
  _SUB_ENUM_ORDER_TYPE._serialized_start=9322
  _SUB_ENUM_ORDER_TYPE._serialized_end=9612
  _SUB_ENUM_ORDER_TYPE_TIME._serialized_start=9615
  _SUB_ENUM_ORDER_TYPE_TIME._serialized_end=9753
  _SUB_ENUM_ORDER_STATE._serialized_start=9756
  _SUB_ENUM_ORDER_STATE._serialized_end=10086
  _SUB_ENUM_POSITION_REASON._serialized_start=10089
  _SUB_ENUM_POSITION_REASON._serialized_end=10240
  _SUB_ENUM_POSITION_TYPE._serialized_start=10242
  _SUB_ENUM_POSITION_TYPE._serialized_end=10321
  _SUB_ENUM_DEAL_REASON._serialized_start=10324
  _SUB_ENUM_DEAL_REASON._serialized_end=10651
  _SUB_ENUM_DEAL_TYPE._serialized_start=10654
  _SUB_ENUM_DEAL_TYPE._serialized_end=11210
  _SUB_ENUM_DEAL_ENTRY._serialized_start=11212
  _SUB_ENUM_DEAL_ENTRY._serialized_end=11333
  _MT5_SUB_ENUM_EVENT_GROUP_TYPE._serialized_start=11335
  _MT5_SUB_ENUM_EVENT_GROUP_TYPE._serialized_end=11400
  _ONTRADETRANSACTIONREQUEST._serialized_start=105
  _ONTRADETRANSACTIONREQUEST._serialized_end=132
  _ONTRADETRANSACTIONREPLY._serialized_start=135
  _ONTRADETRANSACTIONREPLY._serialized_end=264
  _ONTRADETRANSACTIONDATA._serialized_start=267
  _ONTRADETRANSACTIONDATA._serialized_end=609
  _MQLTRADETRANSACTION._serialized_start=612
  _MQLTRADETRANSACTION._serialized_end=1223
  _MQLTRADEREQUEST._serialized_start=1226
  _MQLTRADEREQUEST._serialized_end=1833
  _MQLTRADERESULT._serialized_start=1836
  _MQLTRADERESULT._serialized_end=2174
  _ONPOSITIONSANDPENDINGORDERSTICKETSREQUEST._serialized_start=2176
  _ONPOSITIONSANDPENDINGORDERSTICKETSREQUEST._serialized_end=2254
  _ONPOSITIONSANDPENDINGORDERSTICKETSREPLY._serialized_start=2257
  _ONPOSITIONSANDPENDINGORDERSTICKETSREPLY._serialized_end=2418
  _ONPOSITIONSANDPENDINGORDERSTICKETSDATA._serialized_start=2421
  _ONPOSITIONSANDPENDINGORDERSTICKETSDATA._serialized_end=2602
  _ONPOSITIONPROFITREPLY._serialized_start=2604
  _ONPOSITIONPROFITREPLY._serialized_end=2729
  _ONPOSITIONPROFITDATA._serialized_start=2732
  _ONPOSITIONPROFITDATA._serialized_end=3113
  _ONPOSITIONPROFITREQUEST._serialized_start=3115
  _ONPOSITIONPROFITREQUEST._serialized_end=3202
  _ONPOSITIONPROFITPOSITIONINFO._serialized_start=3204
  _ONPOSITIONPROFITPOSITIONINFO._serialized_end=3306
  _ONEVENTACCOUNTINFO._serialized_start=3309
  _ONEVENTACCOUNTINFO._serialized_end=3468
  _ONTRADEREQUEST._serialized_start=3470
  _ONTRADEREQUEST._serialized_end=3486
  _ONTRADEREPLY._serialized_start=3488
  _ONTRADEREPLY._serialized_end=3595
  _ONTRADEDATA._serialized_start=3598
  _ONTRADEDATA._serialized_end=3812
  _ONTRADEORDERINFO._serialized_start=3815
  _ONTRADEORDERINFO._serialized_end=4584
  _ONTRADEPOSITIONINFO._serialized_start=4587
  _ONTRADEPOSITIONINFO._serialized_end=5064
  _ONTRADEHISTORYDEALINFO._serialized_start=5067
  _ONTRADEHISTORYDEALINFO._serialized_end=5556
  _ONTRADEHISTORYORDERINFO._serialized_start=5559
  _ONTRADEHISTORYORDERINFO._serialized_end=6348
  _ONTRADEORDERSTATECHANGE._serialized_start=6351
  _ONTRADEORDERSTATECHANGE._serialized_end=6487
  _ONTRADEPOSITIONUPDATE._serialized_start=6490
  _ONTRADEPOSITIONUPDATE._serialized_end=6636
  _ONTRADEHISTORYDEALUPDATE._serialized_start=6639
  _ONTRADEHISTORYDEALUPDATE._serialized_end=6802
  _ONTRADEHISTORYORDERUPDATE._serialized_start=6805
  _ONTRADEHISTORYORDERUPDATE._serialized_end=6973
  _ONTADEEVENTDATA._serialized_start=6976
  _ONTADEEVENTDATA._serialized_end=7786
  _ONSYMBOLTICKREQUEST._serialized_start=7788
  _ONSYMBOLTICKREQUEST._serialized_end=7831
  _ONSYMBOLTICKREPLY._serialized_start=7833
  _ONSYMBOLTICKREPLY._serialized_end=7950
  _ONSYMBOLTICKDATA._serialized_start=7952
  _ONSYMBOLTICKDATA._serialized_end=8065
  _MRPCSUBSCRIPTIONMQLTICK._serialized_start=8068
  _MRPCSUBSCRIPTIONMQLTICK._serialized_end=8261
  _SUBSCRIPTIONSERVICE._serialized_start=11403
  _SUBSCRIPTIONSERVICE._serialized_end=11936
# @@protoc_insertion_point(module_scope)
