# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mt5-term-api-account-helper.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from . import mrpc_mt5_error_pb2 as mrpc__mt5__error__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!mt5-term-api-account-helper.proto\x12\x0cmt5_term_api\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x14mrpc-mt5-error.proto\"\xf1\x02\n\x17PositionsHistoryRequest\x12\x44\n\tsort_type\x18\x01 \x01(\x0e\x32\x31.mt5_term_api.AH_ENUM_POSITIONS_HISTORY_SORT_TYPE\x12@\n\x17position_open_time_from\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x12>\n\x15position_open_time_to\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01\x88\x01\x01\x12\x18\n\x0bpage_number\x18\x04 \x01(\x05H\x02\x88\x01\x01\x12\x1b\n\x0eitems_per_page\x18\x05 \x01(\x05H\x03\x88\x01\x01\x42\x1a\n\x18_position_open_time_fromB\x18\n\x16_position_open_time_toB\x0e\n\x0c_page_numberB\x11\n\x0f_items_per_page\"}\n\x15PositionsHistoryReply\x12\x32\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\".mt5_term_api.PositionsHistoryDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"T\n\x14PositionsHistoryData\x12<\n\x11history_positions\x18\x01 \x03(\x0b\x32!.mt5_term_api.PositionHistoryInfo\"\xca\x03\n\x13PositionHistoryInfo\x12\r\n\x05index\x18\x01 \x01(\x05\x12\x17\n\x0fposition_ticket\x18\x02 \x01(\x04\x12\x46\n\norder_type\x18\x03 \x01(\x0e\x32\x32.mt5_term_api.AH_ENUM_POSITIONS_HISTORY_ORDER_TYPE\x12-\n\topen_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nclose_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06volume\x18\x06 \x01(\x01\x12\x12\n\nopen_price\x18\x07 \x01(\x01\x12\x13\n\x0b\x63lose_price\x18\x08 \x01(\x01\x12\x11\n\tstop_loss\x18\t \x01(\x01\x12\x13\n\x0btake_profit\x18\n \x01(\x01\x12\x14\n\x0cmarket_value\x18\x0b \x01(\x01\x12\x12\n\ncommission\x18\x0c \x01(\x01\x12\x0b\n\x03\x66\x65\x65\x18\r \x01(\x01\x12\x0e\n\x06profit\x18\x0e \x01(\x01\x12\x0c\n\x04swap\x18\x0f \x01(\x01\x12\x0f\n\x07\x63omment\x18\x10 \x01(\t\x12\x0e\n\x06symbol\x18\x11 \x01(\t\x12\r\n\x05magic\x18\x12 \x01(\x03\"0\n\x18TickValueWithSizeRequest\x12\x14\n\x0csymbol_names\x18\x01 \x03(\t\"o\n\x16TickValueWithSizeReply\x12\x31\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32#.mt5_term_api.TickValueWithSizeData\x12\"\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.Error\"U\n\x15TickValueWithSizeData\x12<\n\x16symbol_tick_size_infos\x18\x01 \x03(\x0b\x32\x1c.mt5_term_api.TickSizeSymbol\"\xb1\x01\n\x0eTickSizeSymbol\x12\r\n\x05Index\x18\x01 \x01(\x05\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12\x16\n\x0eTradeTickValue\x18\x03 \x01(\x01\x12\x1c\n\x14TradeTickValueProfit\x18\x04 \x01(\x01\x12\x1a\n\x12TradeTickValueLoss\x18\x05 \x01(\x01\x12\x15\n\rTradeTickSize\x18\x06 \x01(\x01\x12\x19\n\x11TradeContractSize\x18\x07 \x01(\x01\"\x1c\n\x1aOpenedOrdersTicketsRequest\"\x83\x01\n\x18OpenedOrdersTicketsReply\x12\x35\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32%.mt5_term_api.OpenedOrdersTicketsDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"Y\n\x17OpenedOrdersTicketsData\x12\x1d\n\x15opened_orders_tickets\x18\x01 \x03(\x03\x12\x1f\n\x17opened_position_tickets\x18\x02 \x03(\x03\"\\\n\x13OpenedOrdersRequest\x12\x45\n\rinputSortMode\x18\x01 \x01(\x0e\x32..mt5_term_api.BMT5_ENUM_OPENED_ORDER_SORT_TYPE\"u\n\x11OpenedOrdersReply\x12.\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1e.mt5_term_api.OpenedOrdersDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"|\n\x10OpenedOrdersData\x12\x34\n\ropened_orders\x18\x01 \x03(\x0b\x32\x1d.mt5_term_api.OpenedOrderInfo\x12\x32\n\x0eposition_infos\x18\x02 \x03(\x0b\x32\x1a.mt5_term_api.PositionInfo\"\x95\x04\n\x0cPositionInfo\x12\r\n\x05index\x18\x01 \x01(\r\x12\x0e\n\x06ticket\x18\x02 \x01(\x04\x12-\n\topen_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06volume\x18\x04 \x01(\x01\x12\x12\n\nprice_open\x18\x05 \x01(\x01\x12\x11\n\tstop_loss\x18\x06 \x01(\x01\x12\x13\n\x0btake_profit\x18\x07 \x01(\x01\x12\x15\n\rprice_current\x18\x08 \x01(\x01\x12\x0c\n\x04swap\x18\t \x01(\x01\x12\x0e\n\x06profit\x18\n \x01(\x01\x12\x34\n\x10last_update_time\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x04type\x18\x0c \x01(\x0e\x32%.mt5_term_api.BMT5_ENUM_POSITION_TYPE\x12\x14\n\x0cmagic_number\x18\r \x01(\x03\x12\x12\n\nidentifier\x18\x0e \x01(\x03\x12\x37\n\x06reason\x18\x0f \x01(\x0e\x32\'.mt5_term_api.BMT5_ENUM_POSITION_REASON\x12\x0e\n\x06symbol\x18\x10 \x01(\t\x12\x0f\n\x07\x63omment\x18\x11 \x01(\t\x12\x13\n\x0b\x65xternal_id\x18\x12 \x01(\t\x12\x1b\n\x13position_commission\x18\x13 \x01(\x01\x12\x15\n\raccount_login\x18\x14 \x01(\x03\"\xdf\x05\n\x0fOpenedOrderInfo\x12\r\n\x05index\x18\x01 \x01(\r\x12\x0e\n\x06ticket\x18\x02 \x01(\x04\x12\x15\n\rprice_current\x18\x03 \x01(\x01\x12\x12\n\nprice_open\x18\x04 \x01(\x01\x12\x12\n\nstop_limit\x18\x05 \x01(\x01\x12\x11\n\tstop_loss\x18\x06 \x01(\x01\x12\x13\n\x0btake_profit\x18\x07 \x01(\x01\x12\x16\n\x0evolume_current\x18\x08 \x01(\x01\x12\x16\n\x0evolume_initial\x18\t \x01(\x01\x12\x14\n\x0cmagic_number\x18\n \x01(\x03\x12\x0e\n\x06reason\x18\x0b \x01(\x05\x12\x30\n\x04type\x18\x0c \x01(\x0e\x32\".mt5_term_api.BMT5_ENUM_ORDER_TYPE\x12\x32\n\x05state\x18\r \x01(\x0e\x32#.mt5_term_api.BMT5_ENUM_ORDER_STATE\x12\x33\n\x0ftime_expiration\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ntime_setup\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\ttime_done\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12@\n\x0ctype_filling\x18\x11 \x01(\x0e\x32*.mt5_term_api.BMT5_ENUM_ORDER_TYPE_FILLING\x12:\n\ttype_time\x18\x12 \x01(\x0e\x32\'.mt5_term_api.BMT5_ENUM_ORDER_TYPE_TIME\x12\x13\n\x0bposition_id\x18\x13 \x01(\x03\x12\x16\n\x0eposition_by_id\x18\x14 \x01(\x03\x12\x0e\n\x06symbol\x18\x15 \x01(\t\x12\x13\n\x0b\x65xternal_id\x18\x16 \x01(\t\x12\x0f\n\x07\x63omment\x18\x17 \x01(\t\x12\x15\n\raccount_login\x18\x18 \x01(\x03\"\xe3\x01\n\x13OrderHistoryRequest\x12-\n\tinputFrom\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07inputTo\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x46\n\rinputSortMode\x18\x03 \x01(\x0e\x32/.mt5_term_api.BMT5_ENUM_ORDER_HISTORY_SORT_TYPE\x12\x12\n\npageNumber\x18\x04 \x01(\x05\x12\x14\n\x0citemsPerPage\x18\x05 \x01(\x05\"v\n\x11OrderHistoryReply\x12/\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1f.mt5_term_api.OrdersHistoryDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"\x82\x01\n\x11OrdersHistoryData\x12\x12\n\narrayTotal\x18\x01 \x01(\x05\x12\x12\n\npageNumber\x18\x02 \x01(\x05\x12\x14\n\x0citemsPerPage\x18\x03 \x01(\x05\x12/\n\x0chistory_data\x18\x04 \x03(\x0b\x32\x19.mt5_term_api.HistoryData\"\x88\x01\n\x0bHistoryData\x12\r\n\x05index\x18\x01 \x01(\r\x12\x35\n\rhistory_order\x18\x02 \x01(\x0b\x32\x1e.mt5_term_api.OrderHistoryData\x12\x33\n\x0chistory_deal\x18\x03 \x01(\x0b\x32\x1d.mt5_term_api.DealHistoryData\"\xd6\x03\n\x0f\x44\x65\x61lHistoryData\x12\x0e\n\x06ticket\x18\x01 \x01(\x04\x12\x0e\n\x06profit\x18\x02 \x01(\x01\x12\x12\n\ncommission\x18\x03 \x01(\x01\x12\x0b\n\x03\x66\x65\x65\x18\x04 \x01(\x01\x12\r\n\x05price\x18\x05 \x01(\x01\x12\x11\n\tstop_loss\x18\x06 \x01(\x01\x12\x13\n\x0btake_profit\x18\x07 \x01(\x01\x12\x0c\n\x04swap\x18\x08 \x01(\x01\x12\x0e\n\x06volume\x18\t \x01(\x01\x12;\n\nentry_type\x18\n \x01(\x0e\x32\'.mt5_term_api.BMT5_ENUM_DEAL_ENTRY_TYPE\x12(\n\x04time\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x04type\x18\x0c \x01(\x0e\x32!.mt5_term_api.BMT5_ENUM_DEAL_TYPE\x12\x33\n\x06reason\x18\r \x01(\x0e\x32#.mt5_term_api.BMT5_ENUM_DEAL_REASON\x12\x13\n\x0bposition_id\x18\x0e \x01(\x04\x12\x0f\n\x07\x63omment\x18\x0f \x01(\t\x12\x0e\n\x06symbol\x18\x10 \x01(\t\x12\x13\n\x0b\x65xternal_id\x18\x11 \x01(\t\x12\x15\n\raccount_login\x18\x12 \x01(\x03\"\xa9\x05\n\x10OrderHistoryData\x12\x0e\n\x06ticket\x18\x01 \x01(\x04\x12.\n\nsetup_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tdone_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x05state\x18\x04 \x01(\x0e\x32#.mt5_term_api.BMT5_ENUM_ORDER_STATE\x12\x15\n\rprice_current\x18\x05 \x01(\x01\x12\x12\n\nprice_open\x18\x06 \x01(\x01\x12\x12\n\nstop_limit\x18\x07 \x01(\x01\x12\x11\n\tstop_loss\x18\x08 \x01(\x01\x12\x13\n\x0btake_profit\x18\t \x01(\x01\x12\x16\n\x0evolume_current\x18\n \x01(\x01\x12\x16\n\x0evolume_initial\x18\x0b \x01(\x01\x12\x14\n\x0cmagic_number\x18\x0c \x01(\x03\x12\x30\n\x04type\x18\r \x01(\x0e\x32\".mt5_term_api.BMT5_ENUM_ORDER_TYPE\x12\x33\n\x0ftime_expiration\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12@\n\x0ctype_filling\x18\x0f \x01(\x0e\x32*.mt5_term_api.BMT5_ENUM_ORDER_TYPE_FILLING\x12:\n\ttype_time\x18\x10 \x01(\x0e\x32\'.mt5_term_api.BMT5_ENUM_ORDER_TYPE_TIME\x12\x13\n\x0bposition_id\x18\x11 \x01(\x04\x12\x0e\n\x06symbol\x18\x12 \x01(\t\x12\x13\n\x0b\x65xternal_id\x18\x13 \x01(\t\x12\x0f\n\x07\x63omment\x18\x14 \x01(\t\x12\x15\n\raccount_login\x18\x15 \x01(\x03\"\x17\n\x15\x41\x63\x63ountSummaryRequest\"y\n\x13\x41\x63\x63ountSummaryReply\x12\x30\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32 .mt5_term_api.AccountSummaryDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"\x86\x03\n\x12\x41\x63\x63ountSummaryData\x12\x15\n\raccount_login\x18\x01 \x01(\x03\x12\x17\n\x0f\x61\x63\x63ount_balance\x18\x02 \x01(\x01\x12\x16\n\x0e\x61\x63\x63ount_equity\x18\x03 \x01(\x01\x12\x19\n\x11\x61\x63\x63ount_user_name\x18\x04 \x01(\t\x12\x18\n\x10\x61\x63\x63ount_leverage\x18\x05 \x01(\x03\x12\x42\n\x12\x61\x63\x63ount_trade_mode\x18\x06 \x01(\x0e\x32&.mt5_term_api.MrpcEnumAccountTradeMode\x12\x1c\n\x14\x61\x63\x63ount_company_name\x18\x07 \x01(\t\x12\x18\n\x10\x61\x63\x63ount_currency\x18\x08 \x01(\t\x12/\n\x0bserver_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n&utc_timezone_server_time_shift_minutes\x18\n \x01(\x03\x12\x16\n\x0e\x61\x63\x63ount_credit\x18\x0b \x01(\x01\"\xf2\x01\n\x17SymbolParamsManyRequest\x12\x18\n\x0bsymbol_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x45\n\tsort_type\x18\x02 \x01(\x0e\x32-.mt5_term_api.AH_SYMBOL_PARAMS_MANY_SORT_TYPEH\x01\x88\x01\x01\x12\x18\n\x0bpage_number\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x1b\n\x0eitems_per_page\x18\x04 \x01(\x05H\x03\x88\x01\x01\x42\x0e\n\x0c_symbol_nameB\x0c\n\n_sort_typeB\x0e\n\x0c_page_numberB\x11\n\x0f_items_per_page\"}\n\x15SymbolParamsManyReply\x12\x32\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\".mt5_term_api.SymbolParamsManyDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"\xbd\x01\n\x14SymbolParamsManyData\x12\x34\n\x0csymbol_infos\x18\x01 \x03(\x0b\x32\x1e.mt5_term_api.SymbolParameters\x12\x15\n\rsymbols_total\x18\x02 \x01(\x05\x12\x18\n\x0bpage_number\x18\x03 \x01(\x05H\x00\x88\x01\x01\x12\x1b\n\x0eitems_per_page\x18\x04 \x01(\x05H\x01\x88\x01\x01\x42\x0e\n\x0c_page_numberB\x11\n\x0f_items_per_page\"\xbb\x18\n\x10SymbolParameters\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03\x62id\x18\x02 \x01(\x01\x12\x10\n\x08\x62id_high\x18\x03 \x01(\x01\x12\x0f\n\x07\x62id_low\x18\x04 \x01(\x01\x12\x0b\n\x03\x61sk\x18\x05 \x01(\x01\x12\x10\n\x08\x61sk_high\x18\x06 \x01(\x01\x12\x0f\n\x07\x61sk_low\x18\x07 \x01(\x01\x12\x0c\n\x04last\x18\x08 \x01(\x01\x12\x11\n\tlast_high\x18\t \x01(\x01\x12\x10\n\x08last_low\x18\n \x01(\x01\x12\x13\n\x0bvolume_real\x18\x0b \x01(\x01\x12\x18\n\x10volume_high_real\x18\x0c \x01(\x01\x12\x17\n\x0fvolume_low_real\x18\r \x01(\x01\x12\x15\n\roption_strike\x18\x0e \x01(\x01\x12\r\n\x05point\x18\x0f \x01(\x01\x12\x18\n\x10trade_tick_value\x18\x10 \x01(\x01\x12\x1f\n\x17trade_tick_value_profit\x18\x11 \x01(\x01\x12\x1d\n\x15trade_tick_value_loss\x18\x12 \x01(\x01\x12\x17\n\x0ftrade_tick_size\x18\x13 \x01(\x01\x12\x1b\n\x13trade_contract_size\x18\x14 \x01(\x01\x12\x1e\n\x16trade_accrued_interest\x18\x15 \x01(\x01\x12\x18\n\x10trade_face_value\x18\x16 \x01(\x01\x12\x1c\n\x14trade_liquidity_rate\x18\x17 \x01(\x01\x12\x12\n\nvolume_min\x18\x18 \x01(\x01\x12\x12\n\nvolume_max\x18\x19 \x01(\x01\x12\x13\n\x0bvolume_step\x18\x1a \x01(\x01\x12\x14\n\x0cvolume_limit\x18\x1b \x01(\x01\x12\x11\n\tswap_long\x18\x1c \x01(\x01\x12\x12\n\nswap_short\x18\x1d \x01(\x01\x12\x13\n\x0bswap_sunday\x18\x1e \x01(\x01\x12\x13\n\x0bswap_monday\x18\x1f \x01(\x01\x12\x14\n\x0cswap_tuesday\x18  \x01(\x01\x12\x16\n\x0eswap_wednesday\x18! \x01(\x01\x12\x15\n\rswap_thursday\x18\" \x01(\x01\x12\x13\n\x0bswap_friday\x18# \x01(\x01\x12\x15\n\rswap_saturday\x18$ \x01(\x01\x12\x16\n\x0emargin_initial\x18% \x01(\x01\x12\x1a\n\x12margin_maintenance\x18& \x01(\x01\x12\x16\n\x0esession_volume\x18\' \x01(\x01\x12\x18\n\x10session_turnover\x18( \x01(\x01\x12\x18\n\x10session_interest\x18) \x01(\x01\x12!\n\x19session_buy_orders_volume\x18* \x01(\x01\x12\"\n\x1asession_sell_orders_volume\x18+ \x01(\x01\x12\x14\n\x0csession_open\x18, \x01(\x01\x12\x15\n\rsession_close\x18- \x01(\x01\x12\x12\n\nsession_aw\x18. \x01(\x01\x12 \n\x18session_price_settlement\x18/ \x01(\x01\x12\x1f\n\x17session_price_limit_min\x18\x30 \x01(\x01\x12\x1f\n\x17session_price_limit_max\x18\x31 \x01(\x01\x12\x15\n\rmargin_hedged\x18\x32 \x01(\x01\x12\x14\n\x0cprice_change\x18\x33 \x01(\x01\x12\x18\n\x10price_volatility\x18\x34 \x01(\x01\x12\x19\n\x11price_theoretical\x18\x35 \x01(\x01\x12\x13\n\x0bprice_delta\x18\x36 \x01(\x01\x12\x13\n\x0bprice_theta\x18\x37 \x01(\x01\x12\x13\n\x0bprice_gamma\x18\x38 \x01(\x01\x12\x12\n\nprice_vega\x18\x39 \x01(\x01\x12\x11\n\tprice_rho\x18: \x01(\x01\x12\x13\n\x0bprice_omega\x18; \x01(\x01\x12\x19\n\x11price_sensitivity\x18< \x01(\x01\x12\x35\n\x06sector\x18= \x01(\x0e\x32%.mt5_term_api.BMT5_ENUM_SYMBOL_SECTOR\x12\x39\n\x08industry\x18> \x01(\x0e\x32\'.mt5_term_api.BMT5_ENUM_SYMBOL_INDUSTRY\x12\x0e\n\x06\x63ustom\x18? \x01(\x08\x12\x18\n\x10\x62\x61\x63kground_color\x18@ \x01(\t\x12=\n\nchart_mode\x18\x41 \x01(\x0e\x32).mt5_term_api.BMT5_ENUM_SYMBOL_CHART_MODE\x12\r\n\x05\x65xist\x18\x42 \x01(\x08\x12\x0e\n\x06select\x18\x43 \x01(\x08\x12\x1a\n\x12subscription_delay\x18\x44 \x01(\x05\x12\x0f\n\x07visible\x18\x45 \x01(\x08\x12\x15\n\rsession_deals\x18\x46 \x01(\x03\x12\x1a\n\x12session_buy_orders\x18G \x01(\x03\x12\x1b\n\x13session_sell_orders\x18H \x01(\x03\x12\x0e\n\x06volume\x18I \x01(\x03\x12\x13\n\x0bvolume_high\x18J \x01(\x03\x12\x12\n\nvolume_low\x18K \x01(\x03\x12(\n\x04time\x18L \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08time_msc\x18M \x01(\x03\x12\x0e\n\x06\x64igits\x18N \x01(\x05\x12\x14\n\x0cspread_float\x18O \x01(\x08\x12\x0e\n\x06spread\x18P \x01(\x05\x12\x18\n\x10ticks_book_depth\x18Q \x01(\x05\x12\x41\n\x0ftrade_calc_mode\x18R \x01(\x0e\x32(.mt5_term_api.BMT5_ENUM_SYMBOL_CALC_MODE\x12=\n\ntrade_mode\x18S \x01(\x0e\x32).mt5_term_api.BMT5_ENUM_SYMBOL_TRADE_MODE\x12.\n\nstart_time\x18T \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x0f\x65xpiration_time\x18U \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x19\n\x11trade_stops_level\x18V \x01(\x05\x12\x1a\n\x12trade_freeze_level\x18W \x01(\x05\x12\x46\n\x0etrade_exe_mode\x18X \x01(\x0e\x32..mt5_term_api.BMT5_ENUM_SYMBOL_TRADE_EXECUTION\x12;\n\tswap_mode\x18Y \x01(\x0e\x32(.mt5_term_api.BMT5_ENUM_SYMBOL_SWAP_MODE\x12@\n\x13swap_rollover_3days\x18Z \x01(\x0e\x32#.mt5_term_api.BMT5_ENUM_DAY_OF_WEEK\x12\x1d\n\x15margin_hedged_use_leg\x18[ \x01(\x08\x12\x17\n\x0f\x65xpiration_mode\x18\\ \x01(\x05\x12@\n\x0c\x66illing_mode\x18] \x03(\x0e\x32*.mt5_term_api.BMT5_ENUM_ORDER_TYPE_FILLING\x12\x36\n\norder_mode\x18^ \x01(\x0e\x32\".mt5_term_api.BMT5_ENUM_ORDER_TYPE\x12\x45\n\x0eorder_gtc_mode\x18_ \x01(\x0e\x32-.mt5_term_api.BMT5_ENUM_SYMBOL_ORDER_GTC_MODE\x12?\n\x0boption_mode\x18` \x01(\x0e\x32*.mt5_term_api.BMT5_ENUM_SYMBOL_OPTION_MODE\x12\x41\n\x0coption_right\x18\x61 \x01(\x0e\x32+.mt5_term_api.BMT5_ENUM_SYMBOL_OPTION_RIGHT\x12\r\n\x05\x62\x61sis\x18\x62 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x63 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x64 \x01(\t\x12\x13\n\x0bsector_name\x18\x65 \x01(\t\x12\x15\n\rindustry_name\x18\x66 \x01(\t\x12\x15\n\rcurrency_base\x18g \x01(\t\x12\x17\n\x0f\x63urrency_profit\x18h \x01(\t\x12\x17\n\x0f\x63urrency_margin\x18i \x01(\t\x12\x0c\n\x04\x62\x61nk\x18j \x01(\t\x12\x17\n\x0fsym_description\x18k \x01(\t\x12\x10\n\x08\x65xchange\x18l \x01(\t\x12\x0f\n\x07\x66ormula\x18m \x01(\t\x12\x0c\n\x04isin\x18n \x01(\t\x12\x0c\n\x04page\x18o \x01(\t\x12\x0c\n\x04path\x18p \x01(\t*\x9d\x01\n#AH_ENUM_POSITIONS_HISTORY_SORT_TYPE\x12\x1d\n\x19\x41H_POSITION_OPEN_TIME_ASC\x10\x00\x12\x1e\n\x1a\x41H_POSITION_OPEN_TIME_DESC\x10\x01\x12\x1a\n\x16\x41H_POSITION_TICKET_ASC\x10\x02\x12\x1b\n\x17\x41H_POSITION_TICKET_DESC\x10\x03*\xaa\x02\n$AH_ENUM_POSITIONS_HISTORY_ORDER_TYPE\x12\x15\n\x11\x41H_ORDER_TYPE_BUY\x10\x00\x12\x16\n\x12\x41H_ORDER_TYPE_SELL\x10\x01\x12\x1b\n\x17\x41H_ORDER_TYPE_BUY_LIMIT\x10\x02\x12\x1c\n\x18\x41H_ORDER_TYPE_SELL_LIMIT\x10\x03\x12\x1a\n\x16\x41H_ORDER_TYPE_BUY_STOP\x10\x04\x12\x1b\n\x17\x41H_ORDER_TYPE_SELL_STOP\x10\x05\x12 \n\x1c\x41H_ORDER_TYPE_BUY_STOP_LIMIT\x10\x06\x12!\n\x1d\x41H_ORDER_TYPE_SELL_STOP_LIMIT\x10\x07\x12\x1a\n\x16\x41H_ORDER_TYPE_CLOSE_BY\x10\x08*\xe4\x01\n BMT5_ENUM_OPENED_ORDER_SORT_TYPE\x12+\n\'BMT5_OPENED_ORDER_SORT_BY_OPEN_TIME_ASC\x10\x00\x12,\n(BMT5_OPENED_ORDER_SORT_BY_OPEN_TIME_DESC\x10\x01\x12\x31\n-BMT5_OPENED_ORDER_SORT_BY_ORDER_TICKET_ID_ASC\x10\x02\x12\x32\n.BMT5_OPENED_ORDER_SORT_BY_ORDER_TICKET_ID_DESC\x10\x03*R\n\x17\x42MT5_ENUM_POSITION_TYPE\x12\x1a\n\x16\x42MT5_POSITION_TYPE_BUY\x10\x00\x12\x1b\n\x17\x42MT5_POSITION_TYPE_SELL\x10\x01*\xdb\x01\n\x19\x42MT5_ENUM_POSITION_REASON\x12\x1f\n\x1b\x42MT5_POSITION_REASON_CLIENT\x10\x00\x12\x1f\n\x1b\x42MT5_POSITION_REASON_MOBILE\x10\x01\x12\x1c\n\x18\x42MT5_POSITION_REASON_WEB\x10\x02\x12\x1f\n\x1b\x42MT5_POSITION_REASON_EXPERT\x10\x03\x12\x13\n\x0fORDER_REASON_SL\x10\x04\x12\x13\n\x0fORDER_REASON_TP\x10\x05\x12\x13\n\x0fORDER_REASON_SO\x10\x06*\x8f\x01\n\x19\x42MT5_ENUM_ORDER_TYPE_TIME\x12\x17\n\x13\x42MT5_ORDER_TIME_GTC\x10\x00\x12\x17\n\x13\x42MT5_ORDER_TIME_DAY\x10\x01\x12\x1d\n\x19\x42MT5_ORDER_TIME_SPECIFIED\x10\x02\x12!\n\x1d\x42MT5_ORDER_TIME_SPECIFIED_DAY\x10\x03*\x91\x01\n\x1c\x42MT5_ENUM_ORDER_TYPE_FILLING\x12\x1a\n\x16\x42MT5_ORDER_FILLING_FOK\x10\x00\x12\x1a\n\x16\x42MT5_ORDER_FILLING_IOC\x10\x01\x12\x1a\n\x16\x42MT5_ORDER_FILLING_BOC\x10\x03\x12\x1d\n\x19\x42MT5_ORDER_FILLING_RETURN\x10\x02*\xac\x02\n\x14\x42MT5_ENUM_ORDER_TYPE\x12\x17\n\x13\x42MT5_ORDER_TYPE_BUY\x10\x00\x12\x18\n\x14\x42MT5_ORDER_TYPE_SELL\x10\x01\x12\x1d\n\x19\x42MT5_ORDER_TYPE_BUY_LIMIT\x10\x02\x12\x1e\n\x1a\x42MT5_ORDER_TYPE_SELL_LIMIT\x10\x03\x12\x1c\n\x18\x42MT5_ORDER_TYPE_BUY_STOP\x10\x04\x12\x1d\n\x19\x42MT5_ORDER_TYPE_SELL_STOP\x10\x05\x12\"\n\x1e\x42MT5_ORDER_TYPE_BUY_STOP_LIMIT\x10\x06\x12#\n\x1f\x42MT5_ORDER_TYPE_SELL_STOP_LIMIT\x10\x07\x12\x1c\n\x18\x42MT5_ORDER_TYPE_CLOSE_BY\x10\x08*\xd3\x02\n\x15\x42MT5_ENUM_DEAL_REASON\x12\x1b\n\x17\x42MT5_DEAL_REASON_CLIENT\x10\x00\x12\x1b\n\x17\x42MT5_DEAL_REASON_MOBILE\x10\x01\x12\x18\n\x14\x42MT5_DEAL_REASON_WEB\x10\x02\x12\x1b\n\x17\x42MT5_DEAL_REASON_EXPERT\x10\x03\x12\x17\n\x13\x42MT5_DEAL_REASON_SL\x10\x04\x12\x17\n\x13\x42MT5_DEAL_REASON_TP\x10\x05\x12\x17\n\x13\x42MT5_DEAL_REASON_SO\x10\x06\x12\x1d\n\x19\x42MT5_DEAL_REASON_ROLLOVER\x10\x07\x12\x1c\n\x18\x42MT5_DEAL_REASON_VMARGIN\x10\x08\x12\x1a\n\x16\x42MT5_DEAL_REASON_SPLIT\x10\t\x12%\n!BMT5_DEAL_REASON_CORPORATE_ACTION\x10\n*\xbf\x04\n\x13\x42MT5_ENUM_DEAL_TYPE\x12\x16\n\x12\x42MT5_DEAL_TYPE_BUY\x10\x00\x12\x17\n\x13\x42MT5_DEAL_TYPE_SELL\x10\x01\x12\x1a\n\x16\x42MT5_DEAL_TYPE_BALANCE\x10\x02\x12\x19\n\x15\x42MT5_DEAL_TYPE_CREDIT\x10\x03\x12\x19\n\x15\x42MT5_DEAL_TYPE_CHARGE\x10\x04\x12\x1d\n\x19\x42MT5_DEAL_TYPE_CORRECTION\x10\x05\x12\x18\n\x14\x42MT5_DEAL_TYPE_BONUS\x10\x06\x12\x1d\n\x19\x42MT5_DEAL_TYPE_COMMISSION\x10\x07\x12#\n\x1f\x42MT5_DEAL_TYPE_COMMISSION_DAILY\x10\x08\x12%\n!BMT5_DEAL_TYPE_COMMISSION_MONTHLY\x10\t\x12)\n%BMT5_DEAL_TYPE_COMMISSION_AGENT_DAILY\x10\n\x12+\n\'BMT5_DEAL_TYPE_COMMISSION_AGENT_MONTHLY\x10\x0b\x12\x1b\n\x17\x42MT5_DEAL_TYPE_INTEREST\x10\x0c\x12\x1f\n\x1b\x42MT5_DEAL_TYPE_BUY_CANCELED\x10\r\x12 \n\x1c\x42MT5_DEAL_TYPE_SELL_CANCELED\x10\x0e\x12\x16\n\x12\x42MT5_DEAL_DIVIDEND\x10\x0f\x12\x1e\n\x1a\x42MT5_DEAL_DIVIDEND_FRANKED\x10\x10\x12\x11\n\rBMT5_DEAL_TAX\x10\x11*\x83\x01\n\x19\x42MT5_ENUM_DEAL_ENTRY_TYPE\x12\x16\n\x12\x42MT5_DEAL_ENTRY_IN\x10\x00\x12\x17\n\x13\x42MT5_DEAL_ENTRY_OUT\x10\x01\x12\x19\n\x15\x42MT5_DEAL_ENTRY_INOUT\x10\x02\x12\x1a\n\x16\x42MT5_DEAL_ENTRY_OUT_BY\x10\x03*\xf4\x01\n!BMT5_ENUM_ORDER_HISTORY_SORT_TYPE\x12\x1e\n\x1a\x42MT5_SORT_BY_OPEN_TIME_ASC\x10\x00\x12\x1f\n\x1b\x42MT5_SORT_BY_OPEN_TIME_DESC\x10\x01\x12\x1f\n\x1b\x42MT5_SORT_BY_CLOSE_TIME_ASC\x10\x02\x12 \n\x1c\x42MT5_SORT_BY_CLOSE_TIME_DESC\x10\x03\x12$\n BMT5_SORT_BY_ORDER_TICKET_ID_ASC\x10\x04\x12%\n!BMT5_SORT_BY_ORDER_TICKET_ID_DESC\x10\x05*\xd5\x02\n\x15\x42MT5_ENUM_ORDER_STATE\x12\x1c\n\x18\x42MT5_ORDER_STATE_STARTED\x10\x00\x12\x1b\n\x17\x42MT5_ORDER_STATE_PLACED\x10\x01\x12\x1d\n\x19\x42MT5_ORDER_STATE_CANCELED\x10\x02\x12\x1c\n\x18\x42MT5_ORDER_STATE_PARTIAL\x10\x03\x12\x1b\n\x17\x42MT5_ORDER_STATE_FILLED\x10\x04\x12\x1d\n\x19\x42MT5_ORDER_STATE_REJECTED\x10\x05\x12\x1c\n\x18\x42MT5_ORDER_STATE_EXPIRED\x10\x06\x12 \n\x1c\x42MT5_ORDER_STATE_REQUEST_ADD\x10\x07\x12#\n\x1f\x42MT5_ORDER_STATE_REQUEST_MODIFY\x10\x08\x12#\n\x1f\x42MT5_ORDER_STATE_REQUEST_CANCEL\x10\t*\x83\x01\n\x18MrpcEnumAccountTradeMode\x12 \n\x1cMRPC_ACCOUNT_TRADE_MODE_DEMO\x10\x00\x12#\n\x1fMRPC_ACCOUNT_TRADE_MODE_CONTEST\x10\x01\x12 \n\x1cMRPC_ACCOUNT_TRADE_MODE_REAL\x10\x02*\xd7\x01\n\x1f\x41H_SYMBOL_PARAMS_MANY_SORT_TYPE\x12,\n(AH_PARAMS_MANY_SORT_TYPE_SYMBOL_NAME_ASC\x10\x00\x12-\n)AH_PARAMS_MANY_SORT_TYPE_SYMBOL_NAME_DESC\x10\x01\x12*\n&AH_PARAMS_MANY_SORT_TYPE_MQL_INDEX_ASC\x10\x02\x12+\n\'AH_PARAMS_MANY_SORT_TYPE_MQL_INDEX_DESC\x10\x03*d\n\x1d\x42MT5_ENUM_SYMBOL_OPTION_RIGHT\x12!\n\x1d\x42MT5_SYMBOL_OPTION_RIGHT_CALL\x10\x00\x12 \n\x1c\x42MT5_SYMBOL_OPTION_RIGHT_PUT\x10\x01*j\n\x1c\x42MT5_ENUM_SYMBOL_OPTION_MODE\x12$\n BMT5_SYMBOL_OPTION_MODE_EUROPEAN\x10\x00\x12$\n BMT5_SYMBOL_OPTION_MODE_AMERICAN\x10\x01*\x89\x01\n\x1f\x42MT5_ENUM_SYMBOL_ORDER_GTC_MODE\x12\x1a\n\x16\x42MT5_SYMBOL_ORDERS_GTC\x10\x00\x12\x1c\n\x18\x42MT5_SYMBOL_ORDERS_DAILY\x10\x01\x12,\n(BMT5_SYMBOL_ORDERS_DAILY_EXCLUDING_STOPS\x10\x02*\x96\x01\n\x15\x42MT5_ENUM_DAY_OF_WEEK\x12\x0f\n\x0b\x42MT5_SUNDAY\x10\x00\x12\x0f\n\x0b\x42MT5_MONDAY\x10\x01\x12\x10\n\x0c\x42MT5_TUESDAY\x10\x02\x12\x12\n\x0e\x42MT5_WEDNESDAY\x10\x03\x12\x11\n\rBMT5_THURSDAY\x10\x04\x12\x0f\n\x0b\x42MT5_FRIDAY\x10\x05\x12\x11\n\rBMT5_SATURDAY\x10\x06*\xb4\x03\n\x1a\x42MT5_ENUM_SYMBOL_SWAP_MODE\x12\"\n\x1e\x42MT5_SYMBOL_SWAP_MODE_DISABLED\x10\x00\x12 \n\x1c\x42MT5_SYMBOL_SWAP_MODE_POINTS\x10\x01\x12)\n%BMT5_SYMBOL_SWAP_MODE_CURRENCY_SYMBOL\x10\x02\x12)\n%BMT5_SYMBOL_SWAP_MODE_CURRENCY_MARGIN\x10\x03\x12*\n&BMT5_SYMBOL_SWAP_MODE_CURRENCY_DEPOSIT\x10\x04\x12)\n%BMT5_SYMBOL_SWAP_MODE_CURRENCY_PROFIT\x10\x05\x12*\n&BMT5_SYMBOL_SWAP_MODE_INTEREST_CURRENT\x10\x06\x12\'\n#BMT5_SYMBOL_SWAP_MODE_INTEREST_OPEN\x10\x07\x12(\n$BMT5_SYMBOL_SWAP_MODE_REOPEN_CURRENT\x10\x08\x12$\n BMT5_SYMBOL_SWAP_MODE_REOPEN_BID\x10\t*\xc6\x01\n BMT5_ENUM_SYMBOL_TRADE_EXECUTION\x12\'\n#BMT5_SYMBOL_TRADE_EXECUTION_REQUEST\x10\x00\x12\'\n#BMT5_SYMBOL_TRADE_EXECUTION_INSTANT\x10\x01\x12&\n\"BMT5_SYMBOL_TRADE_EXECUTION_MARKET\x10\x02\x12(\n$BMT5_SYMBOL_TRADE_EXECUTION_EXCHANGE\x10\x03*\xd4\x01\n\x1b\x42MT5_ENUM_SYMBOL_TRADE_MODE\x12#\n\x1f\x42MT5_SYMBOL_TRADE_MODE_DISABLED\x10\x00\x12#\n\x1f\x42MT5_SYMBOL_TRADE_MODE_LONGONLY\x10\x01\x12$\n BMT5_SYMBOL_TRADE_MODE_SHORTONLY\x10\x02\x12$\n BMT5_SYMBOL_TRADE_MODE_CLOSEONLY\x10\x03\x12\x1f\n\x1b\x42MT5_SYMBOL_TRADE_MODE_FULL\x10\x04*\x9c\x04\n\x1a\x42MT5_ENUM_SYMBOL_CALC_MODE\x12\x1f\n\x1b\x42MT5_SYMBOL_CALC_MODE_FOREX\x10\x00\x12+\n\'BMT5_SYMBOL_CALC_MODE_FOREX_NO_LEVERAGE\x10\x01\x12!\n\x1d\x42MT5_SYMBOL_CALC_MODE_FUTURES\x10\x02\x12\x1d\n\x19\x42MT5_SYMBOL_CALC_MODE_CFD\x10\x03\x12\"\n\x1e\x42MT5_SYMBOL_CALC_MODE_CFDINDEX\x10\x04\x12%\n!BMT5_SYMBOL_CALC_MODE_CFDLEVERAGE\x10\x05\x12%\n!BMT5_SYMBOL_CALC_MODE_EXCH_STOCKS\x10\x06\x12&\n\"BMT5_SYMBOL_CALC_MODE_EXCH_FUTURES\x10\x07\x12,\n(BMT5_SYMBOL_CALC_MODE_EXCH_FUTURES_FORTS\x10\x08\x12$\n BMT5_SYMBOL_CALC_MODE_EXCH_BONDS\x10\t\x12*\n&BMT5_SYMBOL_CALC_MODE_EXCH_STOCKS_MOEX\x10\n\x12)\n%BMT5_SYMBOL_CALC_MODE_EXCH_BONDS_MOEX\x10\x0b\x12)\n%BMT5_SYMBOL_CALC_MODE_SERV_COLLATERAL\x10\x0c*\xbf\x03\n\x17\x42MT5_ENUM_SYMBOL_SECTOR\x12\x19\n\x15\x42MT5_SECTOR_UNDEFINED\x10\x00\x12\x1f\n\x1b\x42MT5_SECTOR_BASIC_MATERIALS\x10\x01\x12&\n\"BMT5_SECTOR_COMMUNICATION_SERVICES\x10\x02\x12!\n\x1d\x42MT5_SECTOR_CONSUMER_CYCLICAL\x10\x03\x12\"\n\x1e\x42MT5_SECTOR_CONSUMER_DEFENSIVE\x10\x04\x12\x18\n\x14\x42MT5_SECTOR_CURRENCY\x10\x05\x12\x1f\n\x1b\x42MT5_SECTOR_CURRENCY_CRYPTO\x10\x06\x12\x16\n\x12\x42MT5_SECTOR_ENERGY\x10\x07\x12\x19\n\x15\x42MT5_SECTOR_FINANCIAL\x10\x08\x12\x1a\n\x16\x42MT5_SECTOR_HEALTHCARE\x10\t\x12\x1b\n\x17\x42MT5_SECTOR_INDUSTRIALS\x10\n\x12\x1b\n\x17\x42MT5_SECTOR_REAL_ESTATE\x10\x0b\x12\x1a\n\x16\x42MT5_SECTOR_TECHNOLOGY\x10\x0c\x12\x19\n\x15\x42MT5_SECTOR_UTILITIES\x10\r*^\n\x1b\x42MT5_ENUM_SYMBOL_CHART_MODE\x12\x1e\n\x1a\x42MT5_SYMBOL_CHART_MODE_BID\x10\x00\x12\x1f\n\x1b\x42MT5_SYMBOL_CHART_MODE_LAST\x10\x01*\xa6+\n\x19\x42MT5_ENUM_SYMBOL_INDUSTRY\x12\x1b\n\x17\x42MT5_INDUSTRY_UNDEFINED\x10\x00\x12%\n!BMT5_INDUSTRY_AGRICULTURAL_INPUTS\x10\x01\x12\x1b\n\x17\x42MT5_INDUSTRY_ALUMINIUM\x10\x02\x12$\n BMT5_INDUSTRY_BUILDING_MATERIALS\x10\x03\x12\x1b\n\x17\x42MT5_INDUSTRY_CHEMICALS\x10\x04\x12\x1d\n\x19\x42MT5_INDUSTRY_COKING_COAL\x10\x05\x12\x18\n\x14\x42MT5_INDUSTRY_COPPER\x10\x06\x12\x16\n\x12\x42MT5_INDUSTRY_GOLD\x10\x07\x12\x1d\n\x19\x42MT5_INDUSTRY_LUMBER_WOOD\x10\x08\x12#\n\x1f\x42MT5_INDUSTRY_INDUSTRIAL_METALS\x10\t\x12!\n\x1d\x42MT5_INDUSTRY_PRECIOUS_METALS\x10\n\x12\x17\n\x13\x42MT5_INDUSTRY_PAPER\x10\x0b\x12\x18\n\x14\x42MT5_INDUSTRY_SILVER\x10\x0c\x12%\n!BMT5_INDUSTRY_SPECIALTY_CHEMICALS\x10\r\x12\x17\n\x13\x42MT5_INDUSTRY_STEEL\x10\x0e\x12\x1d\n\x19\x42MT5_INDUSTRY_ADVERTISING\x10\x0f\x12\x1e\n\x1a\x42MT5_INDUSTRY_BROADCASTING\x10\x10\x12#\n\x1f\x42MT5_INDUSTRY_GAMING_MULTIMEDIA\x10\x11\x12\x1f\n\x1b\x42MT5_INDUSTRY_ENTERTAINMENT\x10\x12\x12\"\n\x1e\x42MT5_INDUSTRY_INTERNET_CONTENT\x10\x13\x12\x1c\n\x18\x42MT5_INDUSTRY_PUBLISHING\x10\x14\x12\x19\n\x15\x42MT5_INDUSTRY_TELECOM\x10\x15\x12\'\n#BMT5_INDUSTRY_APPAREL_MANUFACTURING\x10\x16\x12 \n\x1c\x42MT5_INDUSTRY_APPAREL_RETAIL\x10\x17\x12$\n BMT5_INDUSTRY_AUTO_MANUFACTURERS\x10\x18\x12\x1c\n\x18\x42MT5_INDUSTRY_AUTO_PARTS\x10\x19\x12!\n\x1d\x42MT5_INDUSTRY_AUTO_DEALERSHIP\x10\x1a\x12#\n\x1f\x42MT5_INDUSTRY_DEPARTMENT_STORES\x10\x1b\x12&\n\"BMT5_INDUSTRY_FOOTWEAR_ACCESSORIES\x10\x1c\x12\x1d\n\x19\x42MT5_INDUSTRY_FURNISHINGS\x10\x1d\x12\x1a\n\x16\x42MT5_INDUSTRY_GAMBLING\x10\x1e\x12$\n BMT5_INDUSTRY_HOME_IMPROV_RETAIL\x10\x1f\x12!\n\x1d\x42MT5_INDUSTRY_INTERNET_RETAIL\x10 \x12\x19\n\x15\x42MT5_INDUSTRY_LEISURE\x10!\x12\x19\n\x15\x42MT5_INDUSTRY_LODGING\x10\"\x12\x1e\n\x1a\x42MT5_INDUSTRY_LUXURY_GOODS\x10#\x12&\n\"BMT5_INDUSTRY_PACKAGING_CONTAINERS\x10$\x12#\n\x1f\x42MT5_INDUSTRY_PERSONAL_SERVICES\x10%\x12\'\n#BMT5_INDUSTRY_RECREATIONAL_VEHICLES\x10&\x12\'\n#BMT5_INDUSTRY_RESIDENT_CONSTRUCTION\x10\'\x12!\n\x1d\x42MT5_INDUSTRY_RESORTS_CASINOS\x10(\x12\x1d\n\x19\x42MT5_INDUSTRY_RESTAURANTS\x10)\x12\"\n\x1e\x42MT5_INDUSTRY_SPECIALTY_RETAIL\x10*\x12\'\n#BMT5_INDUSTRY_TEXTILE_MANUFACTURING\x10+\x12!\n\x1d\x42MT5_INDUSTRY_TRAVEL_SERVICES\x10,\x12#\n\x1f\x42MT5_INDUSTRY_BEVERAGES_BREWERS\x10-\x12$\n BMT5_INDUSTRY_BEVERAGES_NON_ALCO\x10.\x12$\n BMT5_INDUSTRY_BEVERAGES_WINERIES\x10/\x12\x1f\n\x1b\x42MT5_INDUSTRY_CONFECTIONERS\x10\x30\x12!\n\x1d\x42MT5_INDUSTRY_DISCOUNT_STORES\x10\x31\x12#\n\x1f\x42MT5_INDUSTRY_EDUCATION_TRAINIG\x10\x32\x12\x1f\n\x1b\x42MT5_INDUSTRY_FARM_PRODUCTS\x10\x33\x12#\n\x1f\x42MT5_INDUSTRY_FOOD_DISTRIBUTION\x10\x34\x12 \n\x1c\x42MT5_INDUSTRY_GROCERY_STORES\x10\x35\x12$\n BMT5_INDUSTRY_HOUSEHOLD_PRODUCTS\x10\x36\x12 \n\x1c\x42MT5_INDUSTRY_PACKAGED_FOODS\x10\x37\x12\x19\n\x15\x42MT5_INDUSTRY_TOBACCO\x10\x38\x12\"\n\x1e\x42MT5_INDUSTRY_OIL_GAS_DRILLING\x10\x39\x12\x1c\n\x18\x42MT5_INDUSTRY_OIL_GAS_EP\x10:\x12#\n\x1f\x42MT5_INDUSTRY_OIL_GAS_EQUIPMENT\x10;\x12$\n BMT5_INDUSTRY_OIL_GAS_INTEGRATED\x10<\x12#\n\x1f\x42MT5_INDUSTRY_OIL_GAS_MIDSTREAM\x10=\x12\"\n\x1e\x42MT5_INDUSTRY_OIL_GAS_REFINING\x10>\x12\x1e\n\x1a\x42MT5_INDUSTRY_THERMAL_COAL\x10?\x12\x19\n\x15\x42MT5_INDUSTRY_URANIUM\x10@\x12&\n\"BMT5_INDUSTRY_EXCHANGE_TRADED_FUND\x10\x41\x12#\n\x1f\x42MT5_INDUSTRY_ASSETS_MANAGEMENT\x10\x42\x12#\n\x1f\x42MT5_INDUSTRY_BANKS_DIVERSIFIED\x10\x43\x12 \n\x1c\x42MT5_INDUSTRY_BANKS_REGIONAL\x10\x44\x12!\n\x1d\x42MT5_INDUSTRY_CAPITAL_MARKETS\x10\x45\x12%\n!BMT5_INDUSTRY_CLOSE_END_FUND_DEBT\x10\x46\x12\'\n#BMT5_INDUSTRY_CLOSE_END_FUND_EQUITY\x10G\x12(\n$BMT5_INDUSTRY_CLOSE_END_FUND_FOREIGN\x10H\x12!\n\x1d\x42MT5_INDUSTRY_CREDIT_SERVICES\x10I\x12(\n$BMT5_INDUSTRY_FINANCIAL_CONGLOMERATE\x10J\x12)\n%BMT5_INDUSTRY_FINANCIAL_DATA_EXCHANGE\x10K\x12#\n\x1f\x42MT5_INDUSTRY_INSURANCE_BROKERS\x10L\x12\'\n#BMT5_INDUSTRY_INSURANCE_DIVERSIFIED\x10M\x12 \n\x1c\x42MT5_INDUSTRY_INSURANCE_LIFE\x10N\x12$\n BMT5_INDUSTRY_INSURANCE_PROPERTY\x10O\x12\'\n#BMT5_INDUSTRY_INSURANCE_REINSURANCE\x10P\x12%\n!BMT5_INDUSTRY_INSURANCE_SPECIALTY\x10Q\x12\"\n\x1e\x42MT5_INDUSTRY_MORTGAGE_FINANCE\x10R\x12!\n\x1d\x42MT5_INDUSTRY_SHELL_COMPANIES\x10S\x12\x1f\n\x1b\x42MT5_INDUSTRY_BIOTECHNOLOGY\x10T\x12&\n\"BMT5_INDUSTRY_DIAGNOSTICS_RESEARCH\x10U\x12%\n!BMT5_INDUSTRY_DRUGS_MANUFACTURERS\x10V\x12*\n&BMT5_INDUSTRY_DRUGS_MANUFACTURERS_SPEC\x10W\x12\"\n\x1e\x42MT5_INDUSTRY_HEALTHCARE_PLANS\x10X\x12$\n BMT5_INDUSTRY_HEALTH_INFORMATION\x10Y\x12$\n BMT5_INDUSTRY_MEDICAL_FACILITIES\x10Z\x12!\n\x1d\x42MT5_INDUSTRY_MEDICAL_DEVICES\x10[\x12&\n\"BMT5_INDUSTRY_MEDICAL_DISTRIBUTION\x10\\\x12%\n!BMT5_INDUSTRY_MEDICAL_INSTRUMENTS\x10]\x12!\n\x1d\x42MT5_INDUSTRY_PHARM_RETAILERS\x10^\x12#\n\x1f\x42MT5_INDUSTRY_AEROSPACE_DEFENSE\x10_\x12\x1a\n\x16\x42MT5_INDUSTRY_AIRLINES\x10`\x12#\n\x1f\x42MT5_INDUSTRY_AIRPORTS_SERVICES\x10\x61\x12#\n\x1f\x42MT5_INDUSTRY_BUILDING_PRODUCTS\x10\x62\x12$\n BMT5_INDUSTRY_BUSINESS_EQUIPMENT\x10\x63\x12\x1f\n\x1b\x42MT5_INDUSTRY_CONGLOMERATES\x10\x64\x12%\n!BMT5_INDUSTRY_CONSULTING_SERVICES\x10\x65\x12&\n\"BMT5_INDUSTRY_ELECTRICAL_EQUIPMENT\x10\x66\x12*\n&BMT5_INDUSTRY_ENGINEERING_CONSTRUCTION\x10g\x12&\n\"BMT5_INDUSTRY_FARM_HEAVY_MACHINERY\x10h\x12)\n%BMT5_INDUSTRY_INDUSTRIAL_DISTRIBUTION\x10i\x12+\n\'BMT5_INDUSTRY_INFRASTRUCTURE_OPERATIONS\x10j\x12#\n\x1f\x42MT5_INDUSTRY_FREIGHT_LOGISTICS\x10k\x12!\n\x1d\x42MT5_INDUSTRY_MARINE_SHIPPING\x10l\x12#\n\x1f\x42MT5_INDUSTRY_METAL_FABRICATION\x10m\x12#\n\x1f\x42MT5_INDUSTRY_POLLUTION_CONTROL\x10n\x12\x1b\n\x17\x42MT5_INDUSTRY_RAILROADS\x10o\x12 \n\x1c\x42MT5_INDUSTRY_RENTAL_LEASING\x10p\x12%\n!BMT5_INDUSTRY_SECURITY_PROTECTION\x10q\x12,\n(BMT5_INDUSTRY_SPEALITY_BUSINESS_SERVICES\x10r\x12$\n BMT5_INDUSTRY_SPEALITY_MACHINERY\x10s\x12%\n!BMT5_INDUSTRY_STUFFING_EMPLOYMENT\x10t\x12#\n\x1f\x42MT5_INDUSTRY_TOOLS_ACCESSORIES\x10u\x12\x1a\n\x16\x42MT5_INDUSTRY_TRUCKING\x10v\x12\"\n\x1e\x42MT5_INDUSTRY_WASTE_MANAGEMENT\x10w\x12)\n%BMT5_INDUSTRY_REAL_ESTATE_DEVELOPMENT\x10x\x12)\n%BMT5_INDUSTRY_REAL_ESTATE_DIVERSIFIED\x10y\x12&\n\"BMT5_INDUSTRY_REAL_ESTATE_SERVICES\x10z\x12\"\n\x1e\x42MT5_INDUSTRY_REIT_DIVERSIFIED\x10{\x12 \n\x1c\x42MT5_INDUSTRY_REIT_HEALTCARE\x10|\x12\"\n\x1e\x42MT5_INDUSTRY_REIT_HOTEL_MOTEL\x10}\x12!\n\x1d\x42MT5_INDUSTRY_REIT_INDUSTRIAL\x10~\x12\x1e\n\x1a\x42MT5_INDUSTRY_REIT_MORTAGE\x10\x7f\x12\x1e\n\x19\x42MT5_INDUSTRY_REIT_OFFICE\x10\x80\x01\x12\"\n\x1d\x42MT5_INDUSTRY_REIT_RESIDENTAL\x10\x81\x01\x12\x1e\n\x19\x42MT5_INDUSTRY_REIT_RETAIL\x10\x82\x01\x12\"\n\x1d\x42MT5_INDUSTRY_REIT_SPECIALITY\x10\x83\x01\x12*\n%BMT5_INDUSTRY_COMMUNICATION_EQUIPMENT\x10\x84\x01\x12$\n\x1f\x42MT5_INDUSTRY_COMPUTER_HARDWARE\x10\x85\x01\x12\'\n\"BMT5_INDUSTRY_CONSUMER_ELECTRONICS\x10\x86\x01\x12(\n#BMT5_INDUSTRY_ELECTRONIC_COMPONENTS\x10\x87\x01\x12*\n%BMT5_INDUSTRY_ELECTRONIC_DISTRIBUTION\x10\x88\x01\x12\x1e\n\x19\x42MT5_INDUSTRY_IT_SERVICES\x10\x89\x01\x12)\n$BMT5_INDUSTRY_SCIENTIFIC_INSTRUMENTS\x10\x8a\x01\x12*\n%BMT5_INDUSTRY_SEMICONDUCTOR_EQUIPMENT\x10\x8b\x01\x12!\n\x1c\x42MT5_INDUSTRY_SEMICONDUCTORS\x10\x8c\x01\x12\'\n\"BMT5_INDUSTRY_SOFTWARE_APPLICATION\x10\x8d\x01\x12*\n%BMT5_INDUSTRY_SOFTWARE_INFRASTRUCTURE\x10\x8e\x01\x12\x18\n\x13\x42MT5_INDUSTRY_SOLAR\x10\x8f\x01\x12(\n#BMT5_INDUSTRY_UTILITIES_DIVERSIFIED\x10\x90\x01\x12+\n&BMT5_INDUSTRY_UTILITIES_POWERPRODUCERS\x10\x91\x01\x12&\n!BMT5_INDUSTRY_UTILITIES_RENEWABLE\x10\x92\x01\x12/\n*BMT5_INDUSTRY_UTILITIES_REGULATED_ELECTRIC\x10\x93\x01\x12*\n%BMT5_INDUSTRY_UTILITIES_REGULATED_GAS\x10\x94\x01\x12,\n\'BMT5_INDUSTRY_UTILITIES_REGULATED_WATER\x10\x95\x01\x12\"\n\x1d\x42MT5_INDUSTRY_UTILITIES_FIRST\x10\x96\x01\x12!\n\x1c\x42MT5_INDUSTRY_UTILITIES_LAST\x10\x97\x01\x32\xd5\x06\n\rAccountHelper\x12q\n\x0e\x41\x63\x63ountSummary\x12#.mt5_term_api.AccountSummaryRequest\x1a!.mt5_term_api.AccountSummaryReply\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/AccountSummary\x12i\n\x0cOrderHistory\x12!.mt5_term_api.OrderHistoryRequest\x1a\x1f.mt5_term_api.OrderHistoryReply\"\x15\x82\xd3\xe4\x93\x02\x0f\x12\r/OrderHistory\x12i\n\x0cOpenedOrders\x12!.mt5_term_api.OpenedOrdersRequest\x1a\x1f.mt5_term_api.OpenedOrdersReply\"\x15\x82\xd3\xe4\x93\x02\x0f\x12\r/OpenedOrders\x12\x85\x01\n\x13OpenedOrdersTickets\x12(.mt5_term_api.OpenedOrdersTicketsRequest\x1a&.mt5_term_api.OpenedOrdersTicketsReply\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/OpenedOrdersTickets\x12y\n\x10SymbolParamsMany\x12%.mt5_term_api.SymbolParamsManyRequest\x1a#.mt5_term_api.SymbolParamsManyReply\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/SymbolParamsMany\x12}\n\x11TickValueWithSize\x12&.mt5_term_api.TickValueWithSizeRequest\x1a$.mt5_term_api.TickValueWithSizeReply\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/TickValueWithSize\x12y\n\x10PositionsHistory\x12%.mt5_term_api.PositionsHistoryRequest\x1a#.mt5_term_api.PositionsHistoryReply\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/PositionsHistoryBBZ1git.mtapi.io/root/mrpc-proto.git/mt5/libraries/go\xaa\x02\x0cmt5_term_apib\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mt5_term_api_account_helper_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1git.mtapi.io/root/mrpc-proto.git/mt5/libraries/go\252\002\014mt5_term_api'
  _ACCOUNTHELPER.methods_by_name['AccountSummary']._options = None
  _ACCOUNTHELPER.methods_by_name['AccountSummary']._serialized_options = b'\202\323\344\223\002\021\022\017/AccountSummary'
  _ACCOUNTHELPER.methods_by_name['OrderHistory']._options = None
  _ACCOUNTHELPER.methods_by_name['OrderHistory']._serialized_options = b'\202\323\344\223\002\017\022\r/OrderHistory'
  _ACCOUNTHELPER.methods_by_name['OpenedOrders']._options = None
  _ACCOUNTHELPER.methods_by_name['OpenedOrders']._serialized_options = b'\202\323\344\223\002\017\022\r/OpenedOrders'
  _ACCOUNTHELPER.methods_by_name['OpenedOrdersTickets']._options = None
  _ACCOUNTHELPER.methods_by_name['OpenedOrdersTickets']._serialized_options = b'\202\323\344\223\002\026\022\024/OpenedOrdersTickets'
  _ACCOUNTHELPER.methods_by_name['SymbolParamsMany']._options = None
  _ACCOUNTHELPER.methods_by_name['SymbolParamsMany']._serialized_options = b'\202\323\344\223\002\023\022\021/SymbolParamsMany'
  _ACCOUNTHELPER.methods_by_name['TickValueWithSize']._options = None
  _ACCOUNTHELPER.methods_by_name['TickValueWithSize']._serialized_options = b'\202\323\344\223\002\024\022\022/TickValueWithSize'
  _ACCOUNTHELPER.methods_by_name['PositionsHistory']._options = None
  _ACCOUNTHELPER.methods_by_name['PositionsHistory']._serialized_options = b'\202\323\344\223\002\023\022\021/PositionsHistory'
  _AH_ENUM_POSITIONS_HISTORY_SORT_TYPE._serialized_start=9499
  _AH_ENUM_POSITIONS_HISTORY_SORT_TYPE._serialized_end=9656
  _AH_ENUM_POSITIONS_HISTORY_ORDER_TYPE._serialized_start=9659
  _AH_ENUM_POSITIONS_HISTORY_ORDER_TYPE._serialized_end=9957
  _BMT5_ENUM_OPENED_ORDER_SORT_TYPE._serialized_start=9960
  _BMT5_ENUM_OPENED_ORDER_SORT_TYPE._serialized_end=10188
  _BMT5_ENUM_POSITION_TYPE._serialized_start=10190
  _BMT5_ENUM_POSITION_TYPE._serialized_end=10272
  _BMT5_ENUM_POSITION_REASON._serialized_start=10275
  _BMT5_ENUM_POSITION_REASON._serialized_end=10494
  _BMT5_ENUM_ORDER_TYPE_TIME._serialized_start=10497
  _BMT5_ENUM_ORDER_TYPE_TIME._serialized_end=10640
  _BMT5_ENUM_ORDER_TYPE_FILLING._serialized_start=10643
  _BMT5_ENUM_ORDER_TYPE_FILLING._serialized_end=10788
  _BMT5_ENUM_ORDER_TYPE._serialized_start=10791
  _BMT5_ENUM_ORDER_TYPE._serialized_end=11091
  _BMT5_ENUM_DEAL_REASON._serialized_start=11094
  _BMT5_ENUM_DEAL_REASON._serialized_end=11433
  _BMT5_ENUM_DEAL_TYPE._serialized_start=11436
  _BMT5_ENUM_DEAL_TYPE._serialized_end=12011
  _BMT5_ENUM_DEAL_ENTRY_TYPE._serialized_start=12014
  _BMT5_ENUM_DEAL_ENTRY_TYPE._serialized_end=12145
  _BMT5_ENUM_ORDER_HISTORY_SORT_TYPE._serialized_start=12148
  _BMT5_ENUM_ORDER_HISTORY_SORT_TYPE._serialized_end=12392
  _BMT5_ENUM_ORDER_STATE._serialized_start=12395
  _BMT5_ENUM_ORDER_STATE._serialized_end=12736
  _MRPCENUMACCOUNTTRADEMODE._serialized_start=12739
  _MRPCENUMACCOUNTTRADEMODE._serialized_end=12870
  _AH_SYMBOL_PARAMS_MANY_SORT_TYPE._serialized_start=12873
  _AH_SYMBOL_PARAMS_MANY_SORT_TYPE._serialized_end=13088
  _BMT5_ENUM_SYMBOL_OPTION_RIGHT._serialized_start=13090
  _BMT5_ENUM_SYMBOL_OPTION_RIGHT._serialized_end=13190
  _BMT5_ENUM_SYMBOL_OPTION_MODE._serialized_start=13192
  _BMT5_ENUM_SYMBOL_OPTION_MODE._serialized_end=13298
  _BMT5_ENUM_SYMBOL_ORDER_GTC_MODE._serialized_start=13301
  _BMT5_ENUM_SYMBOL_ORDER_GTC_MODE._serialized_end=13438
  _BMT5_ENUM_DAY_OF_WEEK._serialized_start=13441
  _BMT5_ENUM_DAY_OF_WEEK._serialized_end=13591
  _BMT5_ENUM_SYMBOL_SWAP_MODE._serialized_start=13594
  _BMT5_ENUM_SYMBOL_SWAP_MODE._serialized_end=14030
  _BMT5_ENUM_SYMBOL_TRADE_EXECUTION._serialized_start=14033
  _BMT5_ENUM_SYMBOL_TRADE_EXECUTION._serialized_end=14231
  _BMT5_ENUM_SYMBOL_TRADE_MODE._serialized_start=14234
  _BMT5_ENUM_SYMBOL_TRADE_MODE._serialized_end=14446
  _BMT5_ENUM_SYMBOL_CALC_MODE._serialized_start=14449
  _BMT5_ENUM_SYMBOL_CALC_MODE._serialized_end=14989
  _BMT5_ENUM_SYMBOL_SECTOR._serialized_start=14992
  _BMT5_ENUM_SYMBOL_SECTOR._serialized_end=15439
  _BMT5_ENUM_SYMBOL_CHART_MODE._serialized_start=15441
  _BMT5_ENUM_SYMBOL_CHART_MODE._serialized_end=15535
  _BMT5_ENUM_SYMBOL_INDUSTRY._serialized_start=15538
  _BMT5_ENUM_SYMBOL_INDUSTRY._serialized_end=21080
  _POSITIONSHISTORYREQUEST._serialized_start=137
  _POSITIONSHISTORYREQUEST._serialized_end=506
  _POSITIONSHISTORYREPLY._serialized_start=508
  _POSITIONSHISTORYREPLY._serialized_end=633
  _POSITIONSHISTORYDATA._serialized_start=635
  _POSITIONSHISTORYDATA._serialized_end=719
  _POSITIONHISTORYINFO._serialized_start=722
  _POSITIONHISTORYINFO._serialized_end=1180
  _TICKVALUEWITHSIZEREQUEST._serialized_start=1182
  _TICKVALUEWITHSIZEREQUEST._serialized_end=1230
  _TICKVALUEWITHSIZEREPLY._serialized_start=1232
  _TICKVALUEWITHSIZEREPLY._serialized_end=1343
  _TICKVALUEWITHSIZEDATA._serialized_start=1345
  _TICKVALUEWITHSIZEDATA._serialized_end=1430
  _TICKSIZESYMBOL._serialized_start=1433
  _TICKSIZESYMBOL._serialized_end=1610
  _OPENEDORDERSTICKETSREQUEST._serialized_start=1612
  _OPENEDORDERSTICKETSREQUEST._serialized_end=1640
  _OPENEDORDERSTICKETSREPLY._serialized_start=1643
  _OPENEDORDERSTICKETSREPLY._serialized_end=1774
  _OPENEDORDERSTICKETSDATA._serialized_start=1776
  _OPENEDORDERSTICKETSDATA._serialized_end=1865
  _OPENEDORDERSREQUEST._serialized_start=1867
  _OPENEDORDERSREQUEST._serialized_end=1959
  _OPENEDORDERSREPLY._serialized_start=1961
  _OPENEDORDERSREPLY._serialized_end=2078
  _OPENEDORDERSDATA._serialized_start=2080
  _OPENEDORDERSDATA._serialized_end=2204
  _POSITIONINFO._serialized_start=2207
  _POSITIONINFO._serialized_end=2740
  _OPENEDORDERINFO._serialized_start=2743
  _OPENEDORDERINFO._serialized_end=3478
  _ORDERHISTORYREQUEST._serialized_start=3481
  _ORDERHISTORYREQUEST._serialized_end=3708
  _ORDERHISTORYREPLY._serialized_start=3710
  _ORDERHISTORYREPLY._serialized_end=3828
  _ORDERSHISTORYDATA._serialized_start=3831
  _ORDERSHISTORYDATA._serialized_end=3961
  _HISTORYDATA._serialized_start=3964
  _HISTORYDATA._serialized_end=4100
  _DEALHISTORYDATA._serialized_start=4103
  _DEALHISTORYDATA._serialized_end=4573
  _ORDERHISTORYDATA._serialized_start=4576
  _ORDERHISTORYDATA._serialized_end=5257
  _ACCOUNTSUMMARYREQUEST._serialized_start=5259
  _ACCOUNTSUMMARYREQUEST._serialized_end=5282
  _ACCOUNTSUMMARYREPLY._serialized_start=5284
  _ACCOUNTSUMMARYREPLY._serialized_end=5405
  _ACCOUNTSUMMARYDATA._serialized_start=5408
  _ACCOUNTSUMMARYDATA._serialized_end=5798
  _SYMBOLPARAMSMANYREQUEST._serialized_start=5801
  _SYMBOLPARAMSMANYREQUEST._serialized_end=6043
  _SYMBOLPARAMSMANYREPLY._serialized_start=6045
  _SYMBOLPARAMSMANYREPLY._serialized_end=6170
  _SYMBOLPARAMSMANYDATA._serialized_start=6173
  _SYMBOLPARAMSMANYDATA._serialized_end=6362
  _SYMBOLPARAMETERS._serialized_start=6365
  _SYMBOLPARAMETERS._serialized_end=9496
  _ACCOUNTHELPER._serialized_start=21083
  _ACCOUNTHELPER._serialized_end=21936
# @@protoc_insertion_point(module_scope)
