# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mt5-term-api-account-information.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from . import mrpc_mt5_error_pb2 as mrpc__mt5__error__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&mt5-term-api-account-information.proto\x12\x0cmt5_term_api\x1a\x1cgoogle/api/annotations.proto\x1a\x14mrpc-mt5-error.proto\"\\\n\x18\x41\x63\x63ountInfoDoubleRequest\x12@\n\x0bproperty_id\x18\x01 \x01(\x0e\x32+.mt5_term_api.AccountInfoDoublePropertyType\"\x7f\n\x16\x41\x63\x63ountInfoDoubleReply\x12\x33\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32#.mt5_term_api.AccountInfoDoubleDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"0\n\x15\x41\x63\x63ountInfoDoubleData\x12\x17\n\x0frequested_value\x18\x01 \x01(\x01\"^\n\x19\x41\x63\x63ountInfoIntegerRequest\x12\x41\n\x0bproperty_id\x18\x01 \x01(\x0e\x32,.mt5_term_api.AccountInfoIntegerPropertyType\"\x81\x01\n\x17\x41\x63\x63ountInfoIntegerReply\x12\x34\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32$.mt5_term_api.AccountInfoIntegerDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"1\n\x16\x41\x63\x63ountInfoIntegerData\x12\x17\n\x0frequested_value\x18\x01 \x01(\x03\"\\\n\x18\x41\x63\x63ountInfoStringRequest\x12@\n\x0bproperty_id\x18\x01 \x01(\x0e\x32+.mt5_term_api.AccountInfoStringPropertyType\"\x7f\n\x16\x41\x63\x63ountInfoStringReply\x12\x33\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32#.mt5_term_api.AccountInfoStringDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"0\n\x15\x41\x63\x63ountInfoStringData\x12\x17\n\x0frequested_value\x18\x01 \x01(\t*\xf6\x02\n\x1d\x41\x63\x63ountInfoDoublePropertyType\x12\x13\n\x0f\x41\x43\x43OUNT_BALANCE\x10\x00\x12\x12\n\x0e\x41\x43\x43OUNT_CREDIT\x10\x01\x12\x12\n\x0e\x41\x43\x43OUNT_PROFIT\x10\x02\x12\x12\n\x0e\x41\x43\x43OUNT_EQUITY\x10\x03\x12\x12\n\x0e\x41\x43\x43OUNT_MARGIN\x10\x04\x12\x17\n\x13\x41\x43\x43OUNT_MARGIN_FREE\x10\x05\x12\x18\n\x14\x41\x43\x43OUNT_MARGIN_LEVEL\x10\x06\x12\x1a\n\x16\x41\x43\x43OUNT_MARGIN_SO_CALL\x10\x07\x12\x18\n\x14\x41\x43\x43OUNT_MARGIN_SO_SO\x10\x08\x12\x1a\n\x16\x41\x43\x43OUNT_MARGIN_INITIAL\x10\t\x12\x1e\n\x1a\x41\x43\x43OUNT_MARGIN_MAINTENANCE\x10\n\x12\x12\n\x0e\x41\x43\x43OUNT_ASSETS\x10\x0b\x12\x17\n\x13\x41\x43\x43OUNT_LIABILITIES\x10\x0c\x12\x1e\n\x1a\x41\x43\x43OUNT_COMMISSION_BLOCKED\x10\r*\xb5\x02\n\x1e\x41\x63\x63ountInfoIntegerPropertyType\x12\x11\n\rACCOUNT_LOGIN\x10\x00\x12\x16\n\x12\x41\x43\x43OUNT_TRADE_MODE\x10\x01\x12\x14\n\x10\x41\x43\x43OUNT_LEVERAGE\x10\x02\x12\x18\n\x14\x41\x43\x43OUNT_LIMIT_ORDERS\x10\x03\x12\x1a\n\x16\x41\x43\x43OUNT_MARGIN_SO_MODE\x10\x04\x12\x19\n\x15\x41\x43\x43OUNT_TRADE_ALLOWED\x10\x05\x12\x18\n\x14\x41\x43\x43OUNT_TRADE_EXPERT\x10\x06\x12\x17\n\x13\x41\x43\x43OUNT_MARGIN_MODE\x10\x07\x12\x1b\n\x17\x41\x43\x43OUNT_CURRENCY_DIGITS\x10\x08\x12\x16\n\x12\x41\x43\x43OUNT_FIFO_CLOSE\x10\t\x12\x19\n\x15\x41\x43\x43OUNT_HEDGE_ALLOWED\x10\n*p\n\x1d\x41\x63\x63ountInfoStringPropertyType\x12\x10\n\x0c\x41\x43\x43OUNT_NAME\x10\x00\x12\x12\n\x0e\x41\x43\x43OUNT_SERVER\x10\x01\x12\x14\n\x10\x41\x43\x43OUNT_CURRENCY\x10\x02\x12\x13\n\x0f\x41\x43\x43OUNT_COMPANY\x10\x03\x32\x96\x03\n\x12\x41\x63\x63ountInformation\x12}\n\x11\x41\x63\x63ountInfoDouble\x12&.mt5_term_api.AccountInfoDoubleRequest\x1a$.mt5_term_api.AccountInfoDoubleReply\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/AccountInfoDouble\x12\x81\x01\n\x12\x41\x63\x63ountInfoInteger\x12\'.mt5_term_api.AccountInfoIntegerRequest\x1a%.mt5_term_api.AccountInfoIntegerReply\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/AccountInfoInteger\x12}\n\x11\x41\x63\x63ountInfoString\x12&.mt5_term_api.AccountInfoStringRequest\x1a$.mt5_term_api.AccountInfoStringReply\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/AccountInfoStringBBZ1git.mtapi.io/root/mrpc-proto.git/mt5/libraries/go\xaa\x02\x0cmt5_term_apib\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mt5_term_api_account_information_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1git.mtapi.io/root/mrpc-proto.git/mt5/libraries/go\252\002\014mt5_term_api'
  _ACCOUNTINFORMATION.methods_by_name['AccountInfoDouble']._options = None
  _ACCOUNTINFORMATION.methods_by_name['AccountInfoDouble']._serialized_options = b'\202\323\344\223\002\024\022\022/AccountInfoDouble'
  _ACCOUNTINFORMATION.methods_by_name['AccountInfoInteger']._options = None
  _ACCOUNTINFORMATION.methods_by_name['AccountInfoInteger']._serialized_options = b'\202\323\344\223\002\025\022\023/AccountInfoInteger'
  _ACCOUNTINFORMATION.methods_by_name['AccountInfoString']._options = None
  _ACCOUNTINFORMATION.methods_by_name['AccountInfoString']._serialized_options = b'\202\323\344\223\002\024\022\022/AccountInfoString'
  _ACCOUNTINFODOUBLEPROPERTYTYPE._serialized_start=934
  _ACCOUNTINFODOUBLEPROPERTYTYPE._serialized_end=1308
  _ACCOUNTINFOINTEGERPROPERTYTYPE._serialized_start=1311
  _ACCOUNTINFOINTEGERPROPERTYTYPE._serialized_end=1620
  _ACCOUNTINFOSTRINGPROPERTYTYPE._serialized_start=1622
  _ACCOUNTINFOSTRINGPROPERTYTYPE._serialized_end=1734
  _ACCOUNTINFODOUBLEREQUEST._serialized_start=108
  _ACCOUNTINFODOUBLEREQUEST._serialized_end=200
  _ACCOUNTINFODOUBLEREPLY._serialized_start=202
  _ACCOUNTINFODOUBLEREPLY._serialized_end=329
  _ACCOUNTINFODOUBLEDATA._serialized_start=331
  _ACCOUNTINFODOUBLEDATA._serialized_end=379
  _ACCOUNTINFOINTEGERREQUEST._serialized_start=381
  _ACCOUNTINFOINTEGERREQUEST._serialized_end=475
  _ACCOUNTINFOINTEGERREPLY._serialized_start=478
  _ACCOUNTINFOINTEGERREPLY._serialized_end=607
  _ACCOUNTINFOINTEGERDATA._serialized_start=609
  _ACCOUNTINFOINTEGERDATA._serialized_end=658
  _ACCOUNTINFOSTRINGREQUEST._serialized_start=660
  _ACCOUNTINFOSTRINGREQUEST._serialized_end=752
  _ACCOUNTINFOSTRINGREPLY._serialized_start=754
  _ACCOUNTINFOSTRINGREPLY._serialized_end=881
  _ACCOUNTINFOSTRINGDATA._serialized_start=883
  _ACCOUNTINFOSTRINGDATA._serialized_end=931
  _ACCOUNTINFORMATION._serialized_start=1737
  _ACCOUNTINFORMATION._serialized_end=2143
# @@protoc_insertion_point(module_scope)
