# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mt5-term-api-trade-functions.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import mrpc_mt5_error_pb2 as mrpc__mt5__error__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"mt5-term-api-trade-functions.proto\x12\x0cmt5_term_api\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x14mrpc-mt5-error.proto\"\x82\x01\n\x16OrderCalcMarginRequest\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x34\n\norder_type\x18\x02 \x01(\x0e\x32 .mt5_term_api.ENUM_ORDER_TYPE_TF\x12\x0e\n\x06volume\x18\x03 \x01(\x01\x12\x12\n\nopen_price\x18\x04 \x01(\x01\"{\n\x14OrderCalcMarginReply\x12\x31\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32!.mt5_term_api.OrderCalcMarginDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"%\n\x13OrderCalcMarginData\x12\x0e\n\x06margin\x18\x01 \x01(\x01\"\x97\x01\n\x16OrderCalcProfitRequest\x12\x34\n\norder_type\x18\x01 \x01(\x0e\x32 .mt5_term_api.ENUM_ORDER_TYPE_TF\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12\x0e\n\x06volume\x18\x03 \x01(\x01\x12\x12\n\nopen_price\x18\x04 \x01(\x01\x12\x13\n\x0b\x63lose_price\x18\x05 \x01(\x01\"{\n\x14OrderCalcProfitReply\x12\x31\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32!.mt5_term_api.OrderCalcProfitDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"%\n\x13OrderCalcProfitData\x12\x0e\n\x06profit\x18\x01 \x01(\x01\"Q\n\x11OrderCheckRequest\x12<\n\x11mql_trade_request\x18\x01 \x01(\x0b\x32!.mt5_term_api.MrpcMqlTradeRequest\"q\n\x0fOrderCheckReply\x12,\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1c.mt5_term_api.OrderCheckDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"W\n\x0eOrderCheckData\x12\x45\n\x16mql_trade_check_result\x18\x01 \x01(\x0b\x32%.mt5_term_api.MrpcMqlTradeCheckResult\"\xa2\x04\n\x13MrpcMqlTradeRequest\x12=\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32-.mt5_term_api.MRPC_ENUM_TRADE_REQUEST_ACTIONS\x12#\n\x1b\x65xpert_advisor_magic_number\x18\x02 \x01(\x04\x12\r\n\x05order\x18\x03 \x01(\x04\x12\x0e\n\x06symbol\x18\x04 \x01(\t\x12\x0e\n\x06volume\x18\x05 \x01(\x01\x12\r\n\x05price\x18\x06 \x01(\x01\x12\x12\n\nstop_limit\x18\x07 \x01(\x01\x12\x11\n\tstop_loss\x18\x08 \x01(\x01\x12\x13\n\x0btake_profit\x18\t \x01(\x01\x12\x11\n\tdeviation\x18\n \x01(\x04\x12\x34\n\norder_type\x18\x0b \x01(\x0e\x32 .mt5_term_api.ENUM_ORDER_TYPE_TF\x12@\n\x0ctype_filling\x18\x0c \x01(\x0e\x32*.mt5_term_api.MRPC_ENUM_ORDER_TYPE_FILLING\x12:\n\ttype_time\x18\r \x01(\x0e\x32\'.mt5_term_api.MRPC_ENUM_ORDER_TYPE_TIME\x12.\n\nexpiration\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x63omment\x18\x0f \x01(\t\x12\x10\n\x08position\x18\x10 \x01(\x04\x12\x13\n\x0bposition_by\x18\x11 \x01(\x04\"\xc3\x01\n\x17MrpcMqlTradeCheckResult\x12\x15\n\rreturned_code\x18\x01 \x01(\r\x12\x1a\n\x12\x62\x61lance_after_deal\x18\x02 \x01(\x01\x12\x19\n\x11\x65quity_after_deal\x18\x03 \x01(\x01\x12\x0e\n\x06profit\x18\x04 \x01(\x01\x12\x0e\n\x06margin\x18\x05 \x01(\x01\x12\x13\n\x0b\x66ree_margin\x18\x06 \x01(\x01\x12\x14\n\x0cmargin_level\x18\x07 \x01(\x01\x12\x0f\n\x07\x63omment\x18\x08 \x01(\t\"y\n\x13PositionsTotalReply\x12\x30\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32 .mt5_term_api.PositionsTotalDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"-\n\x12PositionsTotalData\x12\x17\n\x0ftotal_positions\x18\x01 \x01(\x05*\x98\x02\n\x12\x45NUM_ORDER_TYPE_TF\x12\x15\n\x11ORDER_TYPE_TF_BUY\x10\x00\x12\x16\n\x12ORDER_TYPE_TF_SELL\x10\x01\x12\x1b\n\x17ORDER_TYPE_TF_BUY_LIMIT\x10\x02\x12\x1c\n\x18ORDER_TYPE_TF_SELL_LIMIT\x10\x03\x12\x1a\n\x16ORDER_TYPE_TF_BUY_STOP\x10\x04\x12\x1b\n\x17ORDER_TYPE_TF_SELL_STOP\x10\x05\x12 \n\x1cORDER_TYPE_TF_BUY_STOP_LIMIT\x10\x06\x12!\n\x1dORDER_TYPE_TF_SELL_STOP_LIMIT\x10\x07\x12\x1a\n\x16ORDER_TYPE_TF_CLOSE_BY\x10\x08*\xb6\x01\n\x1fMRPC_ENUM_TRADE_REQUEST_ACTIONS\x12\x15\n\x11TRADE_ACTION_DEAL\x10\x00\x12\x18\n\x14TRADE_ACTION_PENDING\x10\x01\x12\x15\n\x11TRADE_ACTION_SLTP\x10\x02\x12\x17\n\x13TRADE_ACTION_MODIFY\x10\x03\x12\x17\n\x13TRADE_ACTION_REMOVE\x10\x04\x12\x19\n\x15TRADE_ACTION_CLOSE_BY\x10\x05*}\n\x1cMRPC_ENUM_ORDER_TYPE_FILLING\x12\x15\n\x11ORDER_FILLING_FOK\x10\x00\x12\x15\n\x11ORDER_FILLING_IOC\x10\x01\x12\x15\n\x11ORDER_FILLING_BOC\x10\x03\x12\x18\n\x14ORDER_FILLING_RETURN\x10\x02*{\n\x19MRPC_ENUM_ORDER_TYPE_TIME\x12\x12\n\x0eORDER_TIME_GTC\x10\x00\x12\x12\n\x0eORDER_TIME_DAY\x10\x01\x12\x18\n\x14ORDER_TIME_SPECIFIED\x10\x02\x12\x1c\n\x18ORDER_TIME_SPECIFIED_DAY\x10\x03\x32\xc7\x03\n\x0eTradeFunctions\x12u\n\x0fOrderCalcMargin\x12$.mt5_term_api.OrderCalcMarginRequest\x1a\".mt5_term_api.OrderCalcMarginReply\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/OrderCalcMargin\x12u\n\x0fOrderCalcProfit\x12$.mt5_term_api.OrderCalcProfitRequest\x1a\".mt5_term_api.OrderCalcProfitReply\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/OrderCalcProfit\x12\x61\n\nOrderCheck\x12\x1f.mt5_term_api.OrderCheckRequest\x1a\x1d.mt5_term_api.OrderCheckReply\"\x13\x82\xd3\xe4\x93\x02\r\x12\x0b/OrderCheck\x12\x64\n\x0ePositionsTotal\x12\x16.google.protobuf.Empty\x1a!.mt5_term_api.PositionsTotalReply\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/PositionsTotalBBZ1git.mtapi.io/root/mrpc-proto.git/mt5/libraries/go\xaa\x02\x0cmt5_term_apib\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mt5_term_api_trade_functions_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1git.mtapi.io/root/mrpc-proto.git/mt5/libraries/go\252\002\014mt5_term_api'
  _TRADEFUNCTIONS.methods_by_name['OrderCalcMargin']._options = None
  _TRADEFUNCTIONS.methods_by_name['OrderCalcMargin']._serialized_options = b'\202\323\344\223\002\022\022\020/OrderCalcMargin'
  _TRADEFUNCTIONS.methods_by_name['OrderCalcProfit']._options = None
  _TRADEFUNCTIONS.methods_by_name['OrderCalcProfit']._serialized_options = b'\202\323\344\223\002\022\022\020/OrderCalcProfit'
  _TRADEFUNCTIONS.methods_by_name['OrderCheck']._options = None
  _TRADEFUNCTIONS.methods_by_name['OrderCheck']._serialized_options = b'\202\323\344\223\002\r\022\013/OrderCheck'
  _TRADEFUNCTIONS.methods_by_name['PositionsTotal']._options = None
  _TRADEFUNCTIONS.methods_by_name['PositionsTotal']._serialized_options = b'\202\323\344\223\002\021\022\017/PositionsTotal'
  _ENUM_ORDER_TYPE_TF._serialized_start=1986
  _ENUM_ORDER_TYPE_TF._serialized_end=2266
  _MRPC_ENUM_TRADE_REQUEST_ACTIONS._serialized_start=2269
  _MRPC_ENUM_TRADE_REQUEST_ACTIONS._serialized_end=2451
  _MRPC_ENUM_ORDER_TYPE_FILLING._serialized_start=2453
  _MRPC_ENUM_ORDER_TYPE_FILLING._serialized_end=2578
  _MRPC_ENUM_ORDER_TYPE_TIME._serialized_start=2580
  _MRPC_ENUM_ORDER_TYPE_TIME._serialized_end=2703
  _ORDERCALCMARGINREQUEST._serialized_start=167
  _ORDERCALCMARGINREQUEST._serialized_end=297
  _ORDERCALCMARGINREPLY._serialized_start=299
  _ORDERCALCMARGINREPLY._serialized_end=422
  _ORDERCALCMARGINDATA._serialized_start=424
  _ORDERCALCMARGINDATA._serialized_end=461
  _ORDERCALCPROFITREQUEST._serialized_start=464
  _ORDERCALCPROFITREQUEST._serialized_end=615
  _ORDERCALCPROFITREPLY._serialized_start=617
  _ORDERCALCPROFITREPLY._serialized_end=740
  _ORDERCALCPROFITDATA._serialized_start=742
  _ORDERCALCPROFITDATA._serialized_end=779
  _ORDERCHECKREQUEST._serialized_start=781
  _ORDERCHECKREQUEST._serialized_end=862
  _ORDERCHECKREPLY._serialized_start=864
  _ORDERCHECKREPLY._serialized_end=977
  _ORDERCHECKDATA._serialized_start=979
  _ORDERCHECKDATA._serialized_end=1066
  _MRPCMQLTRADEREQUEST._serialized_start=1069
  _MRPCMQLTRADEREQUEST._serialized_end=1615
  _MRPCMQLTRADECHECKRESULT._serialized_start=1618
  _MRPCMQLTRADECHECKRESULT._serialized_end=1813
  _POSITIONSTOTALREPLY._serialized_start=1815
  _POSITIONSTOTALREPLY._serialized_end=1936
  _POSITIONSTOTALDATA._serialized_start=1938
  _POSITIONSTOTALDATA._serialized_end=1983
  _TRADEFUNCTIONS._serialized_start=2706
  _TRADEFUNCTIONS._serialized_end=3161
# @@protoc_insertion_point(module_scope)
